@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Py_CreatorClient.h"
 
@@ -22,7 +35,7 @@ using Atlas::Message::MapType;
 
 static const bool debug_flag = false;
 
-static PyObject * CreatorClient_as_entity(PyCreatorClient * self, PyObject * args)
+static PyObject * CreatorClient_as_entity(PyCreatorClient * self, PyObject *)
 {
 #ifndef NDEBUG
     if (self->m_mind == NULL) {
@@ -30,9 +43,6 @@ static PyObject * CreatorClient_as_entity(PyCreatorClient * self, PyObject * arg
         return NULL;
     }
 #endif // NDEBUG
-    if (!PyArg_ParseTuple(args, "")) {
-        return NULL;
-    }
     PyMessageElement * ret = newPyMessageElement();
     if (ret == NULL) {
         return NULL;
@@ -42,7 +52,8 @@ static PyObject * CreatorClient_as_entity(PyCreatorClient * self, PyObject * arg
     return (PyObject *)ret;
 }
 
-static PyObject * CreatorClient_make(PyCreatorClient * self, PyObject * args)
+static PyObject * CreatorClient_make(PyCreatorClient * self,
+                                     PyRootEntity * entity)
 {
 #ifndef NDEBUG
     if (self->m_mind == NULL) {
@@ -50,10 +61,6 @@ static PyObject * CreatorClient_make(PyCreatorClient * self, PyObject * args)
         return NULL;
     }
 #endif // NDEBUG
-    PyRootEntity * entity = NULL;
-    if (!PyArg_ParseTuple(args, "O", &entity)) {
-        return NULL;
-    }
     if (!PyRootEntity_Check(entity)) {
         PyErr_SetString(PyExc_TypeError, "Can only make Atlas entity");
         return NULL;
@@ -90,7 +97,7 @@ static PyObject * CreatorClient_set(PyCreatorClient * self, PyObject * args)
     return Py_None;
 }
 
-static PyObject * CreatorClient_look(PyCreatorClient * self, PyObject * args)
+static PyObject * CreatorClient_look(PyCreatorClient * self, PyObject * py_id)
 {
 #ifndef NDEBUG
     if (self->m_mind == NULL) {
@@ -98,10 +105,11 @@ static PyObject * CreatorClient_look(PyCreatorClient * self, PyObject * args)
         return NULL;
     }
 #endif // NDEBUG
-    char * id = NULL;
-    if (!PyArg_ParseTuple(args, "s", &id)) {
+    if (!PyString_CheckExact(py_id)) {
+        PyErr_SetString(PyExc_TypeError, "CreatorClient.look must be a string");
         return NULL;
     }
+    char * id = PyString_AsString(py_id);
     Entity * retval = self->m_mind->look(id);
     if (retval == NULL) {
         PyErr_SetString(PyExc_RuntimeError, "Entity look failed");
@@ -112,7 +120,7 @@ static PyObject * CreatorClient_look(PyCreatorClient * self, PyObject * args)
     return (PyObject *)ret;
 }
 static PyObject * CreatorClient_look_for(PyCreatorClient * self,
-                                         PyObject * args)
+                                         PyRootEntity * ent)
 {
 #ifndef NDEBUG
     if (self->m_mind == NULL) {
@@ -120,10 +128,6 @@ static PyObject * CreatorClient_look_for(PyCreatorClient * self,
         return NULL;
     }
 #endif // NDEBUG
-    PyRootEntity * ent;
-    if (!PyArg_ParseTuple(args, "O", &ent)) {
-        return NULL;
-    }
     if (!PyRootEntity_Check(ent)) {
         PyErr_SetString(PyExc_TypeError, "Can only look for Atlas description");
         return NULL;
@@ -138,7 +142,7 @@ static PyObject * CreatorClient_look_for(PyCreatorClient * self,
     return (PyObject *)ret;
 }
 
-static PyObject * CreatorClient_send(PyCreatorClient * self, PyObject * args)
+static PyObject * CreatorClient_send(PyCreatorClient * self, PyOperation * op)
 {
 #ifndef NDEBUG
     if (self->m_mind == NULL) {
@@ -146,10 +150,6 @@ static PyObject * CreatorClient_send(PyCreatorClient * self, PyObject * args)
         return NULL;
     }
 #endif // NDEBUG
-    PyOperation * op;
-    if (!PyArg_ParseTuple(args, "O", &op)) {
-        return NULL;
-    }
     if (!PyOperation_Check(op)) {
         PyErr_SetString(PyExc_TypeError, "Can only send Atlas operation");
         return NULL;
@@ -161,11 +161,11 @@ static PyObject * CreatorClient_send(PyCreatorClient * self, PyObject * args)
 
 static PyMethodDef CreatorClient_methods[] = {
 	{"as_entity",      (PyCFunction)CreatorClient_as_entity, METH_NOARGS},
-	{"make",           (PyCFunction)CreatorClient_make, METH_VARARGS},
-	{"set",            (PyCFunction)CreatorClient_set, METH_VARARGS},
-	{"look",           (PyCFunction)CreatorClient_look, METH_VARARGS},
-	{"look_for",       (PyCFunction)CreatorClient_look_for, METH_VARARGS},
-	{"send",           (PyCFunction)CreatorClient_send, METH_VARARGS},
+	{"make",           (PyCFunction)CreatorClient_make,      METH_O},
+	{"set",            (PyCFunction)CreatorClient_set,       METH_VARARGS},
+	{"look",           (PyCFunction)CreatorClient_look,      METH_O},
+	{"look_for",       (PyCFunction)CreatorClient_look_for,  METH_O},
+	{"send",           (PyCFunction)CreatorClient_send,      METH_O},
 	{NULL,          NULL}           /* sentinel */
 };
 
@@ -208,7 +208,7 @@ static PyObject * CreatorClient_getattr(PyCreatorClient *self, char *name)
     if (strcmp(name, "location") == 0) {
         PyLocation * loc = newPyLocation();
         loc->location = &self->m_mind->m_location;
-        loc->own = 0;
+        loc->owner = self->m_mind;
         return (PyObject *)loc;
     }
     if (strcmp(name, "time") == 0) {
@@ -225,7 +225,7 @@ static PyObject * CreatorClient_getattr(PyCreatorClient *self, char *name)
     }
     Entity * thing = self->m_mind;
     Element attr;
-    if (!thing->get(name, attr)) {
+    if (!thing->getAttr(name, attr)) {
         return Py_FindMethod(CreatorClient_methods, (PyObject *)self, name);
     }
     PyObject * ret = MessageElement_asPyObject(attr);
@@ -270,7 +270,7 @@ static int CreatorClient_setattr(PyCreatorClient *self, char *name, PyObject *v)
     //}
     Element obj = PyObject_asMessageElement(v);
     if (!obj.isNone() && !obj.isMap() && !obj.isList()) {
-        thing->set(name, obj);
+        thing->setAttr(name, obj);
         return 0;
     }
     // If we get here, then the attribute is not Atlas compatable, so we
