@@ -1,14 +1,28 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "ObserverClient.h"
+#include "ClientPropertyManager.h"
 
 #include "rulesets/Python_API.h"
 
 #include "common/globals.h"
 
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 #include <iostream>
 
@@ -59,12 +73,12 @@ int main(int argc, char ** argv)
         std::string arg(argv[optind]);
         std::string::size_type pos = arg.rfind(".");
         if (pos == std::string::npos) {
-            std::cout << "function " << arg << std::endl << std::flush;
+            // std::cout << "function " << arg << std::endl << std::flush;
             function = arg;
         } else {
             package = arg.substr(0, pos);
             function = arg.substr(pos + 1);
-            std::cout << "module.function " << package << "." << function << std::endl << std::flush;
+            // std::cout << "module.function " << package << "." << function << std::endl << std::flush;
         }
     } else if (optind != argc) {
         usage(argv[0]);
@@ -74,6 +88,7 @@ int main(int argc, char ** argv)
     init_python_api();
 
     try {
+        new ClientPropertyManager();
         ObserverClient & observer = *new ObserverClient();
         observer.setServer(server);
         if (observer.setup(account, password) != 0) {
