@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef COMMON_BASE_WORLD_H
 #define COMMON_BASE_WORLD_H
@@ -17,6 +30,8 @@
 #include <cassert>
 
 class Entity;
+class Task;
+class Character;
 
 /// \brief Base class for game world object.
 ///
@@ -66,15 +81,18 @@ class BaseWorld {
     virtual Entity * addEntity(Entity * obj, bool setup = true) = 0;
     virtual Entity * addNewEntity(const std::string &,
                                   const Atlas::Objects::Entity::RootEntity &) = 0;
+    virtual Task * newTask(const std::string &, Character &) = 0;
+    virtual Task * activateTask(const std::string &, const std::string &,
+                                const std::string &, Character &) = 0;
     virtual void message(const Operation &, Entity & obj) = 0;
     virtual Entity * findByName(const std::string & name) = 0;
     virtual Entity * findByType(const std::string & type) = 0;
     virtual float constrainHeight(Entity *, const Point3D &,
                                   const std::string &) = 0;
-    virtual void addPerceptive(const std::string & id) = 0;
+    virtual void addPerceptive(Entity *) = 0;
 
 
-    SigC::Signal1<void, Operation> Dispatching;
+    sigc::signal<void, Operation> Dispatching;
 };
 
 #endif // COMMON_BASE_WORLD_H
