@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Database.h"
 
@@ -14,7 +27,7 @@
 #include <Atlas/Message/Element.h>
 #include <Atlas/Codecs/XML.h>
 
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 #include <iostream>
 #include <sstream>
@@ -167,6 +180,7 @@ bool Database::initRule(bool createTables)
 void Database::shutdownConnection()
 {
     PQfinish(m_connection);
+    m_connection = 0;
 }
 
 Database * Database::instance()
@@ -805,6 +819,10 @@ long Database::newId(std::string & id)
         PQclear(res);
         log(ERROR, "Extra database result to simple query.");
     };
+    if (id.empty()) {
+        log(ERROR, "Unknown error getting ID from database.");
+        return -1;
+    }
     return forceIntegerId(id);
 }
 
