@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2001-2004 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2001-2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "accountbase.h"
 
@@ -45,7 +58,9 @@ bool AccountBase::putAccount(const Atlas::Message::MapType & o)
     values += "'";
 
     std::string id;
-    m_connection.newId(id);
+    if (m_connection.newId(id) < 0) {
+        return false;
+    }
     return m_connection.createSimpleRow("accounts", id, columns, values);
 }
 
