@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000-2004 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2000-2006 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "inheritance.h"
 
@@ -11,13 +24,16 @@
 #include "Cut.h"
 #include "Delve.h"
 #include "Dig.h"
+#include "Drop.h"
 #include "Eat.h"
 #include "Monitor.h"
 #include "Mow.h"
 #include "Nourish.h"
+#include "Pickup.h"
 #include "Setup.h"
 #include "Tick.h"
 #include "Unseen.h"
+#include "Update.h"
 
 #include <Atlas/Objects/Entity.h>
 
@@ -98,6 +114,18 @@ void installCustomOperations()
     Atlas::Objects::Operation::ATTACK_NO = atlas_factories->addFactory("attack", &Atlas::Objects::generic_factory);
     i.opInstall("attack", OP_ATTACK);
 
+    i.addChild(atlasOpDefinition("pickup", "action"));
+    Atlas::Objects::Operation::PICKUP_NO = atlas_factories->addFactory("pickup", &Atlas::Objects::generic_factory);
+    i.opInstall("pickup", OP_PICKUP);
+
+    i.addChild(atlasOpDefinition("drop", "action"));
+    Atlas::Objects::Operation::DROP_NO = atlas_factories->addFactory("drop", &Atlas::Objects::generic_factory);
+    i.opInstall("drop", OP_DROP);
+
+    i.addChild(atlasOpDefinition("update", "tick"));
+    Atlas::Objects::Operation::UPDATE_NO = atlas_factories->addFactory("update", &Atlas::Objects::generic_factory);
+    i.opInstall("update", OP_DROP);
+
 }
 
 void installCustomEntities()
@@ -109,4 +137,6 @@ void installCustomEntities()
     i.addChild(atlasClass("lobby", "admin_entity"));
 
     i.addChild(atlasClass("server", "admin_entity"));
+
+    i.addChild(atlasClass("task", "admin_entity"));
 }
