@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "inheritance.h"
 
@@ -112,21 +125,7 @@ OpNo Inheritance::opEnumerate(const std::string & parent) const
 
 OpNo Inheritance::opEnumerate(const Operation & op) const
 {
-#if 0
-    // FIXME This should no longer be necessary - just return the Atlas number for the class
-    const std::list<std::string> & parents = op->getParents();
-    if (parents.size() != 1) {
-        log(ERROR, "op with no parents");
-    }
-    const std::string & parent = parents.front();
-    OpNo op_no = opEnumerate(parent);
-    if (op_no != op->getClassNo()) {
-        std::cerr << parent << " op does not match " << op_no << "," << op->getClassNo() << std::endl << std::flush;
-    }
-    return op_no;
-#else
     return op->getClassNo();
-#endif
 }
 
 const Atlas::Objects::Root & Inheritance::getClass(const std::string & parent)
