@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -41,6 +54,23 @@ const std::string get_hostname()
     return std::string(host_ident.nodename);
 }
 
+unsigned int security_check()
+{
+    if (getuid() == 0 || geteuid() == 0) {
+        log(ERROR, "Running cyphesis as the superuser is dangerous.");
+        return 0;
+    }
+    return SECURITY_OKAY;
+}
+
+void reduce_priority(int p)
+{
+    // FIXME Make this optional
+    if (nice(p) < 0) {
+        log(ERROR, "Unable to increase nice level to reduce priority");
+    }
+}
+
 extern "C" void shutdown_on_signal(int signo)
 {
     exit_flag = true;
@@ -59,6 +89,7 @@ extern "C" void shutdown_on_signal(int signo)
 extern "C" void report_segfault(int signo)
 {
     log(CRITICAL, "Segmentation fault");
+    log(NOTICE, "Please report this bug to alriddoch@zepler.org");
 
 #if !defined(HAVE_SIGACTION)
     signal(signo, SIG_DFL);
@@ -68,6 +99,7 @@ extern "C" void report_segfault(int signo)
 extern "C" void report_abort(int signo)
 {
     log(CRITICAL, "Aborted");
+    log(NOTICE, "Please report this bug to alriddoch@zepler.org");
 
 #if !defined(HAVE_SIGACTION)
     signal(signo, SIG_DFL);
