@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000-2004 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2000-2006 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef COMMON_TYPES_H
 #define COMMON_TYPES_H
@@ -27,6 +40,7 @@ class Entity;
 #define OP_DELETE Atlas::Objects::Operation::DELETE_NO
 #define OP_DISAPPEARANCE Atlas::Objects::Operation::DISAPPEARANCE_NO
 #define OP_DIVIDE Atlas::Objects::Operation::DIVIDE_NO
+#define OP_DROP Atlas::Objects::Operation::DROP_NO
 #define OP_EAT Atlas::Objects::Operation::EAT_NO
 #define OP_ERROR Atlas::Objects::Operation::ERROR_NO
 #define OP_GET Atlas::Objects::Operation::GET_NO
@@ -38,6 +52,7 @@ class Entity;
 #define OP_MONITOR Atlas::Objects::Operation::MONITOR_NO
 #define OP_MOVE Atlas::Objects::Operation::MOVE_NO
 #define OP_NOURISH Atlas::Objects::Operation::NOURISH_NO
+#define OP_PICKUP Atlas::Objects::Operation::PICKUP_NO
 #define OP_SET Atlas::Objects::Operation::SET_NO
 #define OP_SETUP Atlas::Objects::Operation::SETUP_NO
 #define OP_SIGHT Atlas::Objects::Operation::SIGHT_NO
