@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "BaseMind.h"
 
@@ -408,22 +421,20 @@ void BaseMind::AppearanceOperation(const Operation & op, OpVector & res)
     const std::vector<Root> & args = op->getArgs();
     std::vector<Root>::const_iterator Iend = args.end();
     for (std::vector<Root>::const_iterator I = args.begin(); I != Iend; ++I) {
+        if (!(*I)->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+            log(ERROR, "BaseMind: Appearance op does not have ID");
+            continue;
+        }
         const std::string & id = (*I)->getId();
-        if (id.empty()) { continue; }
         MemEntity * me = m_map.getAdd(id);
-        Element stamp;
         if (me != 0) {
-            if ((*I)->copyAttr("stamp", stamp) == 0) {
-                if (stamp.isNum()) {
-                    if ((int)stamp.asNum() != me->getSeq()) {
-                        Look l;
-                        Anonymous m;
-                        m->setId(id);
-                        l->setArgs1(m);
-                        res.push_back(l);
-                    }
-                } else {
-                    log(ERROR, "BaseMind: Appearance op does not have numeric stamp");
+            if ((*I)->hasAttrFlag(Atlas::Objects::STAMP_FLAG)) {
+                if ((int)(*I)->getStamp() != me->getSeq()) {
+                    Look l;
+                    Anonymous m;
+                    m->setId(id);
+                    l->setArgs1(m);
+                    res.push_back(l);
                 }
             } else {
                 log(ERROR, "BaseMind: Appearance op does not have stamp");
