@@ -1,15 +1,29 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Character.h"
 
 #include "Pedestrian.h"
-#include "Combat.h"
 #include "MindFactory.h"
 #include "BaseMind.h"
 #include "Script.h"
 #include "World.h"
+#include "Task.h"
+#include "StatisticsProperty.h"
 
 #include "common/op_switch.h"
 #include "common/const.h"
@@ -17,7 +31,6 @@
 #include "common/globals.h"
 #include "common/log.h"
 #include "common/inheritance.h"
-#include "common/Property.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
 
@@ -49,10 +62,12 @@ using Atlas::Objects::Operation::Sound;
 using Atlas::Objects::Operation::Tick;
 using Atlas::Objects::Operation::Look;
 using Atlas::Objects::Operation::Move;
+using Atlas::Objects::Operation::Setup;
 using Atlas::Objects::Operation::Action;
 using Atlas::Objects::Operation::Unseen;
 using Atlas::Objects::Operation::Nourish;
 using Atlas::Objects::Operation::Appearance;
+using Atlas::Objects::Operation::Wield;
 using Atlas::Objects::Entity::Anonymous;
 using Atlas::Objects::Entity::RootEntity;
 
@@ -62,7 +77,7 @@ static const bool debug_flag = false;
 
 const double Character::energyConsumption = 0.001;
 const double Character::foodConsumption = 0.1;
-const double Character::weightConsumption = 1.0;
+const double Character::weightConsumption = 0.1;
 const double Character::energyGain = 0.5;
 const double Character::energyLoss = 0.1;
 const double Character::weightGain = 0.5;
@@ -99,6 +114,13 @@ void Character::metabolise(OpVector & res, double ammount)
     res.push_back(s);
 }
 
+void Character::wieldDropped()
+{
+    Wield wield;
+    wield->setTo(getId());
+    sendWorld(wield);
+}
+
 Character::Character(const std::string & id, long intId) :
                                             Character_parent(id, intId),
                                             m_statistics(*this),
@@ -116,6 +138,7 @@ Character::Character(const std::string & id, long intId) :
     m_properties["stamina"] = new Property<double>(m_stamina, 0);
     m_properties["drunkness"] = new Property<double>(m_drunkness, a_drunk);
     m_properties["sex"] = new Property<std::string>(m_sex, a_sex);
+    m_properties["statistics"] = new StatisticsProperty(m_statistics, 0);
     m_properties["right_hand_wield"] = new Property<std::string>(m_rightHandWield, a_rwield);
 }
 
@@ -132,14 +155,50 @@ Character::~Character()
 
 void Character::setTask(Task * task)
 {
+    if (m_task != 0) {
+        clearTask();
+    }
     m_task = task;
     task->incRef();
+
+    updateTask();
+}
+
+void Character::updateTask()
+{
+    if (m_task == 0) {
+        log(ERROR, "Character::updateTask called when no task running");
+    }
+
+    Anonymous set_arg;
+    m_task->addToEntity(set_arg);
+    set_arg->setId(getId());
+
+    Set set;
+    set->setArgs1(set_arg);
+    set->setTo(getId());
+    
+    sendWorld(set);
 }
 
 void Character::clearTask()
 {
+    if (m_task == 0) {
+        log(ERROR, "Character.clearTask: No task currently set");
+        return;
+    }
     m_task->decRef();
     m_task = 0;
+
+    Anonymous set_arg;
+    set_arg->setAttr("tasks", ListType());
+    set_arg->setId(getId());
+
+    Set set;
+    set->setArgs1(set_arg);
+    set->setTo(getId());
+    
+    sendWorld(set);
 }
 
 void Character::ImaginaryOperation(const Operation & op, OpVector & res)
@@ -154,14 +213,15 @@ void Character::SetupOperation(const Operation & op, OpVector & res)
     debug( std::cout << "CHaracter::SetupOperation()" << std::endl
                      << std::flush;);
 
-    if (op->hasAttr("sub_to")) {
-        debug( std::cout << "Setup has sub_to" << std::endl << std::flush;);
+    if (!op->getArgs().empty()) {
+        debug( std::cout << __func__ << " Setup op is for subsystem" << std::endl << std::flush;);
         return;
     }
 
     Appearance app;
     Anonymous app_arg;
     app_arg->setId(getId());
+    app_arg->setStamp(m_seq);
     app->setArgs1(app_arg);
 
     res.push_back(app);
@@ -182,8 +242,9 @@ void Character::SetupOperation(const Operation & op, OpVector & res)
                                                   m_name, m_type);
 
         Operation s(op.copy());
-        // THis is so not the right thing to do
-        s->setAttr("sub_to", "mind");
+        Anonymous setup_arg;
+        setup_arg->setName("mind");
+        s->setArgs1(setup_arg);
         res.push_back(s);
 
         Look l;
@@ -198,58 +259,62 @@ void Character::SetupOperation(const Operation & op, OpVector & res)
 
 void Character::TickOperation(const Operation & op, OpVector & res)
 {
-    Element sub_to;
-    if (op->copyAttr("sub_to", sub_to) == 0) {
-        debug( std::cout << "Has sub_to" << std::endl << std::flush;);
-        if (!sub_to.isString()) {
-            error(op, "Tick op sub_to is not string", res, getId());
-            return;
-        }
-        if (sub_to.String() == "task") {
-            if (m_task == 0) {
-                log(ERROR, "Got Tick op for task, but task is null");
-                return;
-            }
-            m_task->TickOperation(op, res);
-            if (m_task == 0) {
-                log(ERROR, "task is NULL after it processed tick op");
-                return;
-            }
-            if (m_task->obsolete()) {
-                m_task->decRef();
-                m_task = 0;
-            }
-        }
-        return;
-    }
     debug(std::cout << "================================" << std::endl
                     << std::flush;);
     const std::vector<Root> & args = op->getArgs();
     if (!args.empty()) {
-        // Deal with movement.
         const Root & arg = args.front();
-        Element serialno;
-        if (arg->copyAttr("serialno", serialno) == 0 && (serialno.isInt())) {
-            if (serialno.asInt() < m_movement.serialno()) {
-                debug(std::cout << "Old tick" << std::endl << std::flush;);
+        if (arg->getName() == "move") {
+            // Deal with movement.
+            Element serialno;
+            if (arg->copyAttr("serialno", serialno) == 0 && (serialno.isInt())) {
+                if (serialno.asInt() < m_movement.serialno()) {
+                    debug(std::cout << "Old tick" << std::endl << std::flush;);
+                    return;
+                }
+            } else {
+                log(ERROR, "Character::TickOperation: No serialno in tick arg");
+            }
+            Location return_location;
+            if (m_movement.getUpdatedLocation(return_location)) {
                 return;
             }
+            res.push_back(m_movement.generateMove(return_location));
+            Anonymous tick_arg;
+            tick_arg->setName("move");
+            tick_arg->setAttr("serialno", m_movement.serialno());
+            Tick tickOp;
+            tickOp->setTo(getId());
+            tickOp->setFutureSeconds(m_movement.getTickAddition(return_location.pos(), return_location.velocity()));
+            tickOp->setArgs1(tick_arg);
+            res.push_back(tickOp);
+        } else if (arg->getName() == "task") {
+            // Deal with task iteration
+            if (m_task == 0) {
+                return;
+            }
+            Element serialno;
+            if (arg->copyAttr("serialno", serialno) == 0 && (serialno.isInt())) {
+                if (serialno.asInt() != m_task->serialno()) {
+                    debug(std::cout << "Old tick" << std::endl << std::flush;);
+                    return;
+                }
+            } else {
+                log(ERROR, "Character::TickOperation: No serialno in tick arg");
+                return;
+            }
+            m_task->TickOperation(op, res);
+            assert(m_task != 0);
+            if (m_task->obsolete()) {
+                clearTask();
+            } else {
+                updateTask();
+            }
+        } else if (arg->getName() == "mind") {
+            // Do nothing. Passed to mind.
         } else {
-            log(ERROR, "Character::TickOperation: No serialno in tick arg");
+            log(ERROR, String::compose("Tick to unknown subsystem \"%1\" arrived", arg->getName()).c_str());
         }
-        Location return_location;
-        if (m_movement.getUpdatedLocation(return_location)) {
-            return;
-        }
-        res.push_back(m_movement.generateMove(return_location));
-        Anonymous tick_arg;
-        tick_arg->setName("move");
-        tick_arg->setAttr("serialno", m_movement.serialno());
-        Tick tickOp;
-        tickOp->setTo(getId());
-        tickOp->setFutureSeconds(m_movement.getTickAddition(return_location.pos(), return_location.velocity()));
-        tickOp->setArgs1(tick_arg);
-        res.push_back(tickOp);
     } else {
         m_script->operation("tick", op, res);
 
@@ -351,11 +416,26 @@ void Character::NourishOperation(const Operation & op, OpVector & res)
     res.push_back(si);
 }
 
+void Character::UseOperation(const Operation & op, OpVector & res)
+{
+}
+
 void Character::WieldOperation(const Operation & op, OpVector & res)
 {
     if (op->getArgs().empty()) {
-        // FIXME Wield nothing perhaps?
-        error(op, "Wield has no argument", res, getId());
+        // Wield nothing
+        if (m_rightHandWieldConnection.connected()) {
+            m_rightHandWieldConnection.disconnect();
+        }
+
+        Set set;
+        set->setTo(getId());
+        Anonymous set_arg;
+        set_arg->setId(getId());
+        set_arg->setAttr("right_hand_wield", "");
+        set->setArgs1(set_arg);
+        res.push_back(set);
+
         return;
     }
     const Root & arg = op->getArgs().front();
@@ -376,6 +456,10 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
         return;
     }
 
+    if (m_rightHandWieldConnection.connected()) {
+        m_rightHandWieldConnection.disconnect();
+    }
+
     Set set;
     set->setTo(getId());
     Anonymous set_arg;
@@ -384,6 +468,8 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
     set->setArgs1(set_arg);
     res.push_back(set);
 
+    m_rightHandWieldConnection = item->containered.connect(sigc::mem_fun(this, &Character::wieldDropped));
+
     // m_rightHandWield = item->getId();
     debug(std::cout << "Wielding " << item->getId() << std::endl << std::flush;);
 }
@@ -409,44 +495,43 @@ void Character::AttackOperation(const Operation & op, OpVector & res)
     }
 
     if (attacker->m_task != 0) {
-        log(ERROR, "AttackOperation: Attack op aborted because attacker busy");
+        log(ERROR, String::compose("AttackOperation: Attack op aborted because attacker %1(%2) busy", attacker->getId(), attacker->getType()).c_str());
         return;
     }
 
-#if 1
-    Combat * combat = new Combat(*attacker, *this);
+    if (m_task != 0) {
+        log(ERROR, String::compose("AttackOperation: Attack op aborted because defender %1(%2) busy", getId(), getType()).c_str());
+        return;
+    }
 
-    m_task = combat;
-    combat->incRef();
+    Task * combat = m_world->newTask("combat", *this);
 
-    attacker->m_task = combat;
-    combat->incRef();
+    if (combat == 0) {
+        log(ERROR, "Character::AttackOperation: Unable to create combat task");
+        return;
+    }
 
+    setTask(combat);
     m_task->initTask(op, res);
-
-    if (combat->obsolete()) {
-        std::cout << "Attack aborted because one of more character is exhausted" << std::endl << std::flush;
-
-        assert(m_task == 0);
-        assert(attacker->m_task != 0);
-
-        attacker->m_task = 0;
-        combat->decRef();
-
+    if (m_task->obsolete()) {
+        clearTask();
         return;
     }
-#else
-    Task * combat = EntityFactory::instance()->newTask("combat", *attacker);
 
-    m_task = combat;
-    combat->incRef;
+    combat = m_world->newTask("combat", *attacker);
 
-    attacker->m_task = combat;
-    combat->incRef();
+    if (combat == 0) {
+        log(ERROR, "Character::AttackOperation: Unable to create combat task");
+        return;
+    }
 
-    Setup s;
-    m_task->SetupOperation (s, res);
-#endif
+    attacker->setTask(combat);
+    attacker->m_task->initTask(op, res);
+    if (attacker->m_task->obsolete()) {
+        attacker->clearTask();
+        clearTask();
+        return;
+    }
 }
 
 void Character::ChopOperation(const Operation & op, OpVector & res)
@@ -470,8 +555,9 @@ void Character::mindLogoutOperation(const Operation & op, OpVector & res)
 
 void Character::mindActionOperation(const Operation & op, OpVector & res)
 {
-    // FIXME Put this in, and make sure it doesn't happen again.
-    log(WARNING, "Explicit Action operation from client");
+    // FIXME Make sure it doesn't happen again. Action should probably be
+    // removed from the main switch.
+    log(ERROR, "Explicit Action operation from client");
     
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
@@ -509,19 +595,16 @@ void Character::mindAttackOperation(const Operation & op, OpVector & res)
     }
     const std::string & id = arg->getId();
 
-    // FIXME Check current TASK?
-    // If already in combat, probably this should not work.
-    // If doing something else, it gets aborted.
-    // endCurrentTask();
-
     op->setTo(id);
     res.push_back(op);
 }
 
 void Character::mindSetupOperation(const Operation & op, OpVector & res)
 {
+    Anonymous setup_arg;
+    setup_arg->setName("mind");
+    op->setArgs1(setup_arg);
     op->setTo(getId());
-    op->setAttr("sub_to", "mind");
     res.push_back(op);
 }
 
@@ -529,13 +612,29 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
 {
     debug(std::cout << "Got Use op from mind" << std::endl << std::flush;);
 
-    std::string toolId = m_rightHandWield;
+    const std::vector<Root> & args = op->getArgs();
+    if (args.empty()) {
+        if (m_task != 0) {
+            if (!m_task->obsolete()) {
+                m_task->irrelevant();
+            }
+            assert(m_task->obsolete());
+            clearTask();
+        }
+        return;
+    }
 
+    const std::string & toolId = m_rightHandWield;
+
+    if (toolId.empty()) {
+        error(op, "Character::mindUseOp No tool wielded.", res, getId());
+        return;
+    }
     // FIXME Get a tool id from the op attributes?
 
     Entity * tool = m_world->getEntity(toolId);
     if (tool == 0) {
-        error(op, "Use tool does not exist.", res, getId());
+        error(op, "Character::mindUseOp Tool does not exist.", res, getId());
         return;
     }
 
@@ -544,111 +643,106 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
     std::string op_type;
 
     // Determine the operations this tool supports
-    if (tool->get("operations", toolOpAttr)) {
-        if (!toolOpAttr.isList()) {
-            log(ERROR, "Use tool has non list operations list");
-            return;
+    if (!tool->getAttr("operations", toolOpAttr)) {
+        log(NOTICE, "Character::mindUseOp Attempt to use something not a tool");
+        return;
+    }
+
+    if (!toolOpAttr.isList()) {
+        log(ERROR, "Character::mindUseOp Tool has non list operations list");
+        return;
+    }
+    const ListType & toolOpList = toolOpAttr.asList();
+    if (toolOpList.empty()) {
+        log(ERROR, "Character::mindUseOp Tool operation list is empty");
+        return;
+    }
+    ListType::const_iterator J = toolOpList.begin();
+    ListType::const_iterator Jend = toolOpList.end();
+    assert(J != Jend);
+    if (!(*J).isString()) {
+        log(ERROR, "Character::mindUseOp Tool operation list is malformed");
+        return;
+    }
+    op_type = (*J).String();
+    debug(std::cout << "default tool op is " << op_type << std::endl
+                                                        << std::flush;);
+    for (; J != Jend; ++J) {
+        if (!(*J).isString()) {
+            log(ERROR, "Character::mindUseOp Tool has non string in operations list");
+        } else {
+            toolOps.insert((*J).String());
         }
-        const ListType & toolOpList = toolOpAttr.asList();
-        ListType::const_iterator J = toolOpList.begin();
-        ListType::const_iterator Jend = toolOpList.end();
-        if ((J != Jend) && ((*J).isString())) {
-            op_type = (*J).String();
-            debug(std::cout << "default tool op is " << op_type << std::endl
-                                                                << std::flush;);
-        }
-        for (; J != Jend; ++J) {
-            if (!(*J).isString()) {
-                log(ERROR, "Use tool has non string in operations list");
-            } else {
-                toolOps.insert((*J).String());
-            }
-        }
-    } // FIXME else return? Not much can happen if toolOps is empty
+    }
+
+
+    RootEntity entity_arg(0);
+
+    assert(!entity_arg.isValid());
 
     // Look at Use args. If arg is an entity, this is the target.
     // If arg is an operation, this is the operation to be used, and the
     // sub op arg may be an entity specifying target. If op to be used is
     // specified, this is checked against the ops permitted by this tool.
-    Anonymous target;
-    const std::vector<Root> & args = op->getArgs();
-    if (!args.empty()) {
-        const Root & arg = args.front();
-        const std::string & argtype = arg->getObjtype();
-        if (argtype == "op") {
-            // FIXME Check if it really is a RootOperation. if so we can
-            // do the rest more easily.
-            if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
-                (arg->getParents().empty())) {
-                error(op, "Use arg op has malformed parents", res, getId());
-                return;
-            }
-            op_type = arg->getParents().front();
-            debug(std::cout << "Got op type " << op_type << " from arg"
-                            << std::endl << std::flush;);
-            if (toolOps.find(op_type) == toolOps.end()) {
-                error(op, "Use op is not permitted by tool", res, getId());
-                return;
-            }
-            // Check against valid ops
-            Operation arg_op = smart_dynamic_cast<Operation>(arg);
-            if (!arg_op.isValid()) {
-                error(op, "Use op arg is a malformed op", res, getId());
-                return;
-            }
-
-            const std::vector<Root> & arg_op_args = arg_op->getArgs();
-            if (!arg_op_args.empty()) {
-                const Root & arg_op_arg = arg_op_args.front();
-                
-                if (!arg_op_arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-                    error(op, "Use arg entity has no ID", res, getId());
-                    return;
-                }
-                target->setId(arg_op_arg->getId());
-                debug(std::cout << "Got target " << target->getId()
-                                << " from op arg"
-                                << std::endl << std::flush;);
-                // FIXME Duplicated code below (see FIXME)
-                Element pos_attr;
-                if (arg_op_arg->copyAttr("pos", pos_attr) == 0) {
-                    debug(std::cout << "Got a use op with POS"
-                                    << std::endl << std::flush;);
-                    if (!pos_attr.isList()) {
-                        error(op, String::compose("Use arg entity has POS of type %1 rather than list", Element::typeName(pos_attr.getType())).c_str(), res, getId());
-                        return;
-                    }
-                    target->setAttr("pos", pos_attr);
-                }
-            }
-        } else if (argtype == "obj") {
-            if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-                error(op, "Use arg entity has no ID", res, getId());
-                return;
-            }
-            target->setId(arg->getId());
-            debug(std::cout << "Got target " << target->getId()
-                            << " from arg"
-                            << std::endl << std::flush;);
-            // FIXME Duplicated code above (see FIXME)
-            Element pos_attr;
-            if (arg->copyAttr("pos", pos_attr) == 0) {
-                debug(std::cout << "Got a use op with POS"
-                                << std::endl << std::flush;);
-                if (!pos_attr.isList()) {
-                    error(op, String::compose("Use arg entity has POS of type %1 rather than list", Element::typeName(pos_attr.getType())).c_str(), res, getId());
-                    return;
-                }
-                target->setAttr("pos", pos_attr);
-            }
-        } else {
-            error(op, "Use arg has unknown objtype", res, getId());
+    const Root & arg = args.front();
+    const std::string & argtype = arg->getObjtype();
+    if (argtype == "op") {
+        if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
+            (arg->getParents().empty())) {
+            error(op, "Use arg op has malformed parents", res, getId());
             return;
         }
+        op_type = arg->getParents().front();
+        debug(std::cout << "Got op type " << op_type << " from arg"
+                        << std::endl << std::flush;);
+        if (toolOps.find(op_type) == toolOps.end()) {
+            error(op, "Use op is not permitted by tool", res, getId());
+            return;
+        }
+        // Check against valid ops
+        Operation arg_op = smart_dynamic_cast<Operation>(arg);
+        if (!arg_op.isValid()) {
+            error(op, "Use op arg is a malformed op", res, getId());
+            return;
+        }
+
+        const std::vector<Root> & arg_op_args = arg_op->getArgs();
+        if (!arg_op_args.empty()) {
+            entity_arg = smart_dynamic_cast<RootEntity>(arg_op_args.front());
+            if (!entity_arg.isValid()) {
+                error(op, "Use op target is malformed", res, getId());
+                return;
+            }
+        }
+    } else if (argtype == "obj") {
+        entity_arg = smart_dynamic_cast<RootEntity>(arg);
+        if (!entity_arg.isValid()) {
+            error(op, "Use target is malformed", res, getId());
+            return;
+        }
+    } else {
+        error(op, "Use arg has unknown objtype", res, getId());
+        return;
+    }
+
+    Anonymous target;
+    if (!entity_arg.isValid()) {
+        error(op, "Character::mindUseOperation No target specified", res, getId());
+        return;
+    }
+
+    if (!entity_arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        error(op, "Character::mindUseOperation Target entity has no ID", res, getId());
+        return;
+    }
+    target->setId(entity_arg->getId());
+
+    if (entity_arg->hasAttrFlag(Atlas::Objects::Entity::POS_FLAG)) {
+        target->setPos(entity_arg->getPos());
     }
 
     if (op_type.empty()) {
-        error(op, "Use unable to determine op type for tool", res, getId());
+        error(op, "Character::mindUseOperation Unable to determine op type for tool", res, getId());
         return;
     }
 
@@ -658,10 +752,14 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
                     << std::endl << std::flush;);
 
     Root obj = Atlas::Objects::Factories::instance()->createObject(op_type);
+    if (!obj.isValid()) {
+        log(ERROR, String::compose("Character::mindUseOperation Unknown op type %1 requested by %2 tool", op_type, tool->getType()).c_str());
+        return;
+    }
     Operation rop = smart_dynamic_cast<Operation>(obj);
     if (!rop.isValid()) {
-        log(ERROR, String::compose("Character::mindUseMethod: Unknown op type %1 requested by %2 tool", op_type, tool->getType()).c_str());
-        // FIXME Thing hard about how this error is reported. Would the error
+        log(ERROR, String::compose("Character::mindUseOperation Op type %1 requested by %2 tool, but it is not an operation type", op_type, tool->getType()).c_str());
+        // FIXME Think hard about how this error is reported. Would the error
         // make it back to the client if we made an error response?
         return;
     } else if (!target->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
@@ -671,6 +769,31 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
     }
 
     rop->setTo(toolId);
+
+    Entity * target_ent = m_world->getEntity(entity_arg->getId());
+    if (target_ent == 0) {
+        error(op, "Character::mindUseOperation Target does not exist", res, getId());
+        return;
+    }
+
+    Task * task = m_world->activateTask(tool->getType(), op_type, target_ent->getType(), *this);
+    if (task != NULL) {
+        setTask(task);
+        assert(res.empty());
+        m_task->initTask(rop, res);
+        if (m_task->obsolete()) {
+            clearTask();
+        } else if (res.empty()) {
+            // If initialising the task did not result in any operation at all
+            // then the task cannot work correctly. In this case all we can
+            // do is flag an error, and get rid of the task.
+            log(ERROR, String::compose("Character::mindUseOperation Op type %1 of tool %2 activated a task, but it did not initialise", op_type, tool->getType()).c_str());
+            m_task->irrelevant();
+            clearTask();
+        }
+        return;
+    }
+
     res.push_back(rop);
 
     Sight sight;
@@ -691,8 +814,10 @@ void Character::mindWieldOperation(const Operation & op, OpVector & res)
 
 void Character::mindTickOperation(const Operation & op, OpVector & res)
 {
+    Anonymous tick_arg;
+    tick_arg->setName("mind");
+    op->setArgs1(tick_arg);
     op->setTo(getId());
-    op->setAttr("sub_to", "mind");
     res.push_back(op);
 }
 
@@ -718,14 +843,10 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
         return;
     }
     const std::string & other_id = arg->getId();
-    // FIXME We are looking up the object, but the vast majority of the
-    // time we are moving ourselves. Bypass this lookup if possible.
     if (other_id != getId()) {
         debug( std::cout << "Moving something else. " << other_id << std::endl << std::flush;);
         Entity * other = m_world->getEntity(other_id);
         if (other == 0) {
-            log(ERROR, "mindMoveOperation: This move op is for a phoney id");
-            log(NOTICE, "Sending Unseen op back to mind. We should not see this again.");
             Unseen u;
 
             Anonymous unseen_arg;
@@ -737,7 +858,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
             return;
         }
         if ((other->getMass() < 0) ||
-            (other->getMass() > m_statistics.strength())) {
+            (other->getMass() > m_statistics.get("strength"))) {
             debug( std::cout << "We can't move this. Just too heavy" << std::endl << std::flush;);
             return;
         }
@@ -795,8 +916,6 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
         debug(std::cout << "Changing loc" << std::endl << std::flush;);
         Entity * target_loc = m_world->getEntity(new_loc);
         if (target_loc == 0) {
-            log(ERROR, "mindMoveOperation: This move op has phoney loc");
-            log(NOTICE, "Sending Unseen op back to mind. We should not see this again.");
             Unseen u;
 
             Anonymous unseen_arg;
@@ -863,9 +982,6 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
 
     // Need to add the arguments to this op before we return it
     // direction is already a unit vector
-    debug( if (new_pos.isValid()) { std::cout<<"\tUsing target"
-                                           << std::endl
-                                           << std::flush; } );
     if (new_pos.isValid()) {
         m_movement.setTarget(new_pos);
         debug(std::cout << "Target" << new_pos
@@ -885,7 +1001,8 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
     assert(moveOp.isValid());
     res.push_back(moveOp);
 
-    if (ret_location.velocity().isValid() &&
+    if (m_movement.hasTarget() &&
+        ret_location.velocity().isValid() &&
         ret_location.velocity() != Vector3D(0,0,0)) {
 
         Tick tickOp;
@@ -904,6 +1021,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
 
 void Character::mindSetOperation(const Operation & op, OpVector & res)
 {
+    log(WARNING, "Set op from mind");
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
         log(ERROR, "mindSetOperation: set op has no argument");
@@ -990,11 +1108,11 @@ void Character::mindLookOperation(const Operation & op, OpVector & res)
         op->setTo(m_world->m_gameWorld.getId());
     } else {
         const Root & arg = args.front();
-        if (arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-            op->setTo(arg->getId());
-        } else {
-            op->setTo(getId());
+        if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+            log(ERROR, "mindLookOperation: Op has no ID");
+            return;
         }
+        op->setTo(arg->getId());
     }
     debug( std::cout <<"  now to ["<<op->getTo()<<"]"<<std::endl<<std::flush;);
     res.push_back(op);
@@ -1002,6 +1120,8 @@ void Character::mindLookOperation(const Operation & op, OpVector & res)
 
 void Character::mindCutOperation(const Operation & op, OpVector & res)
 {
+    // FIXME This should go very soon, probably elminated from the mind
+    // switch if we can.
     log(WARNING, "mindCutOperation: Unexpected Cut op from mind");
     op->setTo(getId());
     res.push_back(op);
@@ -1009,8 +1129,6 @@ void Character::mindCutOperation(const Operation & op, OpVector & res)
 
 void Character::mindEatOperation(const Operation & op, OpVector & res)
 {
-    // FIXME Need to get what food to eat from the arg, and sort out goals
-    // so they don't set TO
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
         log(ERROR, "mindEatOperation: Op has no ARGS");
@@ -1035,7 +1153,7 @@ void Character::mindTouchOperation(const Operation & op, OpVector & res)
     }
     const Root & arg = args.front();
     if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
-        log(ERROR, "mindTouchOperation: Op has no ARGS");
+        log(ERROR, "mindTouchOperation: Op has no ID");
         return;
     }
     // Pass the modified touch operation on to target.
@@ -1189,13 +1307,19 @@ bool Character::w2mErrorOperation(const Operation & op)
 
 bool Character::w2mOtherOperation(const Operation & op)
 {
-    return true;
+    const std::string & ot = op->getParents().front();
+    if (ot != "update") {
+        log(WARNING, String::compose("Unexpeced %1 op going from world 2 mind", ot).c_str());
+    }
+    return false;
 }
 
 bool Character::w2mSetupOperation(const Operation & op)
 {
-    if (op->hasAttr("sub_to")) {
-        return true;
+    if (!op->getArgs().empty()) {
+        if (op->getArgs().front()->getName() == "mind") {
+            return true;
+        }
     }
     return false;
 }
@@ -1212,8 +1336,10 @@ bool Character::w2mWieldOperation(const Operation & op)
 
 bool Character::w2mTickOperation(const Operation & op)
 {
-    if (op->hasAttr("sub_to")) {
-        return true;
+    if (!op->getArgs().empty()) {
+        if (op->getArgs().front()->getName() == "mind") {
+            return true;
+        }
     }
     return false;
 }
@@ -1316,7 +1442,6 @@ void Character::operation(const Operation & op, OpVector & res)
         for (OpVector::const_iterator I = mres.begin(); I != Iend; ++I) {
             //Operation * mr2 = mind2_res.front();
             // Need to be very careful about what this actually does
-            (*I)->setSerialno(newSerialNo());
             externalOperation(*I);
         }
     }
@@ -1328,21 +1453,17 @@ void Character::externalOperation(const Operation & op)
     OpVector mres;
     mind2body(op, mres);
     
-    // We require that the first op is the direct consequence of the minds
-    // op, so it gets the same serialno
-    // FIXME in Atlas-C++ 0.6 we can do this by relying on being able
-    // to query if an object has a certain attribute. A copied op will have
-    // it, a new op won't.
-    OpVector::const_iterator Ibegin = mres.begin();
+    OpVector::const_iterator I = mres.begin();
     OpVector::const_iterator Iend = mres.end();
-    for (OpVector::const_iterator I = Ibegin; I != Iend; ++I) {
-        if (I == Ibegin) {
-            (*I)->setSerialno(op->getSerialno());
-        } else {
-            (*I)->setSerialno(newSerialNo());
-        }
+
+    // If the original op had a serial no, we assume the first consequence
+    // of that is effectively the same operation.
+    // FIXME Can this be guaranteed by the mind2body phase?
+    if (!op->isDefaultSerialno() && I != Iend) {
+        (*I)->setSerialno(op->getSerialno());
+    }
+
+    for (; I != Iend; ++I) {
         sendWorld(*I);
-        // Don't delete br as it has gone into World's queue
-        // World will deal with it.
     }
 }
