@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef RULESETS_ENTITY_H
 #define RULESETS_ENTITY_H
@@ -160,9 +173,9 @@ class Entity : public BaseEntity {
         return m_attributes;
     }
 
-    bool has(const std::string &) const;
-    bool get(const std::string &, Atlas::Message::Element &) const;
-    void set(const std::string &, const Atlas::Message::Element &);
+    bool hasAttr(const std::string &) const;
+    bool getAttr(const std::string &, Atlas::Message::Element &) const;
+    void setAttr(const std::string &, const Atlas::Message::Element &);
 
     PropertyBase * getProperty(const std::string &) const;
 
@@ -171,6 +184,7 @@ class Entity : public BaseEntity {
 
     void setScript(Script * scrpt);
     void merge(const Atlas::Message::MapType &);
+    void changeContainer(Entity *);
 
     void destroy();
 
@@ -201,7 +215,10 @@ class Entity : public BaseEntity {
     virtual void OtherOperation(const Operation & op, OpVector &);
 
     /// Signal indicating that this entity has been changed
-    SigC::Signal0<void> updated;
+    sigc::signal<void> updated;
+
+    /// Signal indicating that this entity has changed its LOC
+    sigc::signal<void> containered;
 };
 
 inline std::ostream & operator<<(std::ostream& s, Location& v)
