@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Entity.h"
 
@@ -19,9 +32,10 @@ using Atlas::Message::ListType;
 using Atlas::Objects::Entity::RootEntity;
 
 template<>
-void ImmutableProperty<BBox>::get(Element & e) const
+bool ImmutableProperty<BBox>::get(Element & e) const
 {
     e = m_data.toAtlas();
+    return true;
 }
 
 template<>
@@ -49,10 +63,11 @@ void ImmutableProperty<BBox>::add(const std::string & s, const RootEntity & ent)
 }
 
 template<>
-void ImmutableProperty<IdList>::get(Element & e) const
+bool ImmutableProperty<IdList>::get(Element & e) const
 {
     e = Atlas::Message::ListType();
     idListasObject(m_data, e.asList());
+    return true;
 }
 
 template<>
@@ -82,7 +97,7 @@ void ImmutableProperty<IdList>::add(const std::string & s, const RootEntity & en
 }
 
 template<>
-void ImmutableProperty<EntitySet>::get(Element & e) const
+bool ImmutableProperty<EntitySet>::get(Element & e) const
 {
     e = ListType();
     ListType & contlist = e.asList();
@@ -90,6 +105,7 @@ void ImmutableProperty<EntitySet>::get(Element & e) const
     for (EntitySet::const_iterator I = m_data.begin(); I != Iend; ++I) {
         contlist.push_back((*I)->getId());
     }
+    return true;
 }
 
 template<>
@@ -113,7 +129,7 @@ void ImmutableProperty<EntitySet>::add(const std::string & s,
 }
 
 template<>
-void ImmutableProperty<Container>::get(Element & e) const
+bool ImmutableProperty<Container>::get(Element & e) const
 {
     // FIXME Not sure if this is best. Why did we bother to virtualise
     // addToMessage() if we have to do this here?
@@ -123,6 +139,7 @@ void ImmutableProperty<Container>::get(Element & e) const
     for (Container::const_iterator I = m_data.begin(); I != Iend; ++I) {
         contlist.push_back((*I)->getId());
     }
+    return true;
 }
 
 template<>
