@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef RULESETS_MOVEMENT_H
 #define RULESETS_MOVEMENT_H
@@ -20,18 +33,10 @@ class Location;
 class Movement {
   protected:
     Entity & m_body;
-    double m_lastMovementTime;
-    double m_lastCollisionTime;
     Point3D m_targetPos;
-    Point3D m_updatedPos;
     int m_serialno;
-    Point3D m_collPos;
-    Entity * m_collEntity;
-    bool m_collLocChange;
-    bool m_diverted;
-    Vector3D m_collNormal;
 
-    float checkCollisions(const Location & loc);
+    // float checkCollisions(const Location & loc);
   public:
     explicit Movement(Entity & body);
     virtual ~Movement();
@@ -40,6 +45,10 @@ class Movement {
         return m_serialno;
     }
 
+    bool hasTarget() const {
+        return m_targetPos.isValid();
+    }
+
     void setTarget(const Point3D & target) {
         m_targetPos = target;
     }
