@@ -1,13 +1,36 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Py_BBox.h"
 #include "Py_Vector3D.h"
 
 #include "common/log.h"
 
+static PyObject * BBox_sqr_bounding_radius(PyBBox * self)
+{
+    float square_radius = 0;
+    if (self->box.isValid()) {
+        square_radius = boxSquareBoundingRadius(self->box);
+    }
+    return PyFloat_FromDouble(square_radius);
+}
+
 static PyMethodDef BBox_methods[] = {
+    {"square_bounding_radius", (PyCFunction)BBox_sqr_bounding_radius, METH_NOARGS},
     {NULL, NULL}  // sentinel
 };
 
