@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Py_World.h"
 #include "Py_WorldTime.h"
@@ -27,7 +40,7 @@ static PyObject * World_get_time(PyWorld *self)
     return (PyObject *)wtime;
 }
 
-static PyObject * World_get_object(PyWorld *self, PyObject *args)
+static PyObject * World_get_object(PyWorld *self, PyObject * id)
 {
 #ifndef NDEBUG
     if (self->world == NULL) {
@@ -35,11 +48,11 @@ static PyObject * World_get_object(PyWorld *self, PyObject *args)
         return NULL;
     }
 #endif // NDEBUG
-    char * id = NULL;
-    if (!PyArg_ParseTuple(args, "s", &id)) {
+    if (!PyString_CheckExact(id)) {
+        PyErr_SetString(PyExc_TypeError, "World.get_object must be string");
         return NULL;
     }
-    Entity * ent = self->world->getEntity(id);
+    Entity * ent = self->world->getEntity(PyString_AsString(id));
     if (ent == NULL) {
         Py_INCREF(Py_None);
         return Py_None;
@@ -50,7 +63,7 @@ static PyObject * World_get_object(PyWorld *self, PyObject *args)
 
 static PyMethodDef World_methods[] = {
     {"get_time",        (PyCFunction)World_get_time,    METH_NOARGS},
-    {"get_object",      (PyCFunction)World_get_object,  METH_VARARGS},
+    {"get_object",      (PyCFunction)World_get_object,  METH_O},
     {NULL,              NULL}           // sentinel
 };
 
