@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Python.h"
 
@@ -21,6 +34,7 @@
 #include "Py_Operation.h"
 #include "Py_RootEntity.h"
 #include "Py_Oplist.h"
+#include "Py_Statistics.h"
 
 #include "PythonThingScript.h"
 #include "PythonMindScript.h"
@@ -95,7 +109,9 @@ typedef struct {
 
 static void python_log(LogLevel lvl, const char * msg)
 {
-    std::string message(msg);
+    static std::string message;
+
+    message += msg;
     std::string::size_type n = 0;
     std::string::size_type p;
     for (p = message.find_first_of('\n');
@@ -105,16 +121,19 @@ static void python_log(LogLevel lvl, const char * msg)
         n = p + 1;
     }
     if (message.size() > n) {
-        log(lvl, message.substr(n, message.size() - n).c_str());
+        message = message.substr(n, message.size() - n);
+    } else {
+        message.clear();
     }
 }
 
-static PyObject * PyOutLogger_write(PyObject * self, PyObject * args)
+static PyObject * PyOutLogger_write(PyObject * self, PyObject * arg)
 {
-    char * mesg;
-    if (!PyArg_ParseTuple(args, "s", &mesg)) {
+    if (!PyString_CheckExact(arg)) {
+        PyErr_SetString(PyExc_TypeError, "write must be a string");
         return 0;
     }
+    char * mesg = PyString_AsString(arg);
 
     python_log(SCRIPT, mesg);
 
@@ -122,12 +141,13 @@ static PyObject * PyOutLogger_write(PyObject * self, PyObject * args)
     return Py_None;
 }
 
-static PyObject * PyErrLogger_write(PyObject * self, PyObject * args)
+static PyObject * PyErrLogger_write(PyObject * self, PyObject * arg)
 {
-    char * mesg;
-    if (!PyArg_ParseTuple(args, "s", &mesg)) {
+    if (!PyString_CheckExact(arg)) {
+        PyErr_SetString(PyExc_TypeError, "write must be a string");
         return 0;
     }
+    char * mesg = PyString_AsString(arg);
 
     python_log(SCRIPT_ERROR, mesg);
 
@@ -136,12 +156,12 @@ static PyObject * PyErrLogger_write(PyObject * self, PyObject * args)
 }
 
 static PyMethodDef PyOutLogger_methods[] = {
-    {"write",       PyOutLogger_write,          METH_VARARGS},
+    {"write",       PyOutLogger_write,          METH_O},
     {NULL,          NULL}                       /* Sentinel */
 };
 
 static PyMethodDef PyErrLogger_methods[] = {
-    {"write",       PyErrLogger_write,          METH_VARARGS},
+    {"write",       PyErrLogger_write,          METH_O},
     {NULL,          NULL}                       /* Sentinel */
 };
 
@@ -198,128 +218,6 @@ PyTypeObject PyErrLogger_Type = {
         0,                   // tp_hash
 };
 
-//////////////////////////////////////////////////////////////////////////
-// dictlist
-//////////////////////////////////////////////////////////////////////////
-
-static PyObject * dictlist_remove_value(PyObject * self, PyObject * args, PyObject * kwds)
-{
-    PyObject * dict;
-    PyEntity * item;
-    long remove_empty_key = 1;
-    if (!PyArg_ParseTuple(args, "OO|i", &dict, &item, &remove_empty_key)) {
-        return NULL;
-    }
-    int flag = 0;
-    if (!PyDict_Check(dict)) {
-        PyErr_SetString(PyExc_TypeError, "Trying to set item in not dictlist");
-        return NULL;
-    }
-    PyObject * keys = PyDict_Keys(dict);
-    PyObject * values = PyDict_Values(dict);
-
-    if ((keys == NULL) || (values == NULL)) {
-        PyErr_SetString(PyExc_RuntimeError, "Error getting keys from dictlist");
-        return NULL;
-    }
-    int i, size = PyList_Size(keys);
-    for(i = 0; i < size; i++) {
-        PyObject * value = PyList_GetItem(values, i);
-        PyObject * key = PyList_GetItem(keys, i);
-        int j, lsize = PyList_Size(value);
-        for(j = 0; j < lsize; j++) {
-            PyEntity * entry = (PyEntity*)PyList_GetItem(value, j);
-            if (entry->m_entity == item->m_entity) {
-                flag = 1;
-                PyList_SetSlice(value, j, j+1, NULL);
-                j--; lsize--;
-                if ((remove_empty_key !=0) && (PyList_Size(value) == 0)) {
-                    PyDict_DelItem(dict, key);
-                }
-            }
-        }
-    }
-    Py_DECREF(keys);
-    Py_DECREF(values);
-    return PyInt_FromLong(flag);
-}
-
-PyTypeObject dictlist_remove_value_type = {
-        PyObject_HEAD_INIT(&PyType_Type)
-        0,
-        "Function",
-        sizeof(FunctionObject),
-        0,
-        /* methods */
-        (destructor)Function_dealloc,
-        0,              /* tp_print */
-        0,              /* tp_getattr */
-        0,              /* tp_setattr */
-        0,              /* tp_compare */
-        0,              /* tp_repr */
-        0,              /* tp_as_number */
-        0,              /* tp_as_sequence */
-        0,              /* tp_as_mapping */
-        0,              /* tp_hash */
-        dictlist_remove_value,  /* tp_call */
-};
-static PyObject * dictlist_add_value(PyObject * self, PyObject * args, PyObject * kwds)
-{
-    PyObject * dict;
-    PyEntity * item;
-    char * key;
-    if (!PyArg_ParseTuple(args, "OsO", &dict, &key, &item)) {
-        return NULL;
-    }
-    if (!PyDict_Check(dict)) {
-        PyErr_SetString(PyExc_TypeError, "Dict is not a dictionary");
-        return NULL;
-    }
-    PyObject * list = PyDict_GetItemString(dict, key);
-    if (list != NULL) {
-        if (!PyList_Check(list)) {
-            PyErr_SetString(PyExc_TypeError, "Dict does not contain a list");
-            return NULL;
-        }
-        int i, size = PyList_Size(list);
-        for(i = 0; i < size; i++) {
-            PyEntity * entry = (PyEntity*)PyList_GetItem(list,i);
-            if (entry->m_entity == item->m_entity) {
-                goto present;
-            }
-        }
-        PyList_Append(list, (PyObject*)item);
-    } else {
-        list = PyList_New(0);
-        PyList_Append(list, (PyObject*)item);
-        PyDict_SetItemString(dict, key, list);
-        Py_DECREF(list);
-    }
-present:
-    Py_INCREF(Py_None);
-    return Py_None;
-}
-
-PyTypeObject dictlist_add_value_type = {
-        PyObject_HEAD_INIT(&PyType_Type)
-        0,
-        "Function",
-        sizeof(FunctionObject),
-        0,
-        /* methods */
-        (destructor)Function_dealloc,
-        0,              /* tp_print */
-        0,              /* tp_getattr */
-        0,              /* tp_setattr */
-        0,              /* tp_compare */
-        0,              /* tp_repr */
-        0,              /* tp_as_number */
-        0,              /* tp_as_sequence */
-        0,              /* tp_as_mapping */
-        0,              /* tp_hash */
-        dictlist_add_value,     /* tp_call */
-};
-
 static PyObject * Get_PyClass(const std::string & package,
                               const std::string & type)
 {
@@ -351,7 +249,9 @@ static PyObject * Get_PyClass(const std::string & package,
         return NULL;
     }
 #if 0
-    // In later versions of python using PyType_* will become the right thing to do.
+    // In later versions of python using PyType_* will become the right thing
+    // to do. This might become true when things have been done right with
+    // installing types.
     if (PyType_Check(pyClass) == 0) {
         std::cerr << "PyCallable_Check returned true, but PyType_Check returned false " << package << "." << type << std::endl << std::flush;
     } else {
@@ -436,12 +336,8 @@ void Create_PyMind(BaseMind * mind, const std::string & package,
     }
 }
 
-static PyObject * is_location(PyObject * self, PyObject * args)
+static PyObject * is_location(PyObject * self, PyObject * loc)
 {
-    PyObject * loc;
-    if (!PyArg_ParseTuple(args, "O", &loc)) {
-        return NULL;
-    }
     if (PyLocation_Check(loc)) {
         Py_INCREF(Py_True);
         return Py_True;
@@ -516,7 +412,6 @@ static PyObject * location_new(PyObject * self, PyObject * args)
     if ( o == NULL ) {
         return NULL;
     }
-    o->own = 1;
     if (coords == NULL) {
         o->location = new Location(ref_ent);
     } else {
@@ -593,132 +488,6 @@ static PyObject * square_horizontal_distance(PyObject * self, PyObject * args)
     return PyFloat_FromDouble(squareHorizontalDistance(*sloc->location, *oloc->location));
 }
 
-static PyObject * vector3d_new(PyObject * self, PyObject * args)
-{
-        PyVector3D *o;
-        Vector3D val;
-        // We need to deal with actual args here
-        PyObject * clist;
-        switch (PyTuple_Size(args)) {
-            case 0:
-                break;
-            case 1:
-                clist = PyTuple_GetItem(args, 0);
-                if ((!PyList_Check(clist)) || (PyList_Size(clist) != 3)) {
-                    PyErr_SetString(PyExc_TypeError, "Vector3D() from single value must a list 3 long");
-                    return NULL;
-                }
-                for(int i = 0; i < 3; i++) {
-                    PyObject * item = PyList_GetItem(clist, i);
-                    if (PyInt_Check(item)) {
-                        val[i] = (float)PyInt_AsLong(item);
-                    } else if (PyFloat_Check(item)) {
-                        val[i] = PyFloat_AsDouble(item);
-                    } else if (PyMessageElement_Check(item)) {
-                        PyMessageElement * mitem = (PyMessageElement*)item;
-                        if (!mitem->m_obj->isNum()) {
-                            PyErr_SetString(PyExc_TypeError, "Vector3D() must take list of floats, or ints");
-                            return NULL;
-                        }
-                        val[i] = mitem->m_obj->asNum();
-                    } else {
-                        PyErr_SetString(PyExc_TypeError, "Vector3D() must take list of floats, or ints");
-                        return NULL;
-                    }
-                }
-                val.setValid();
-                break;
-            case 3:
-                for(int i = 0; i < 3; i++) {
-                    PyObject * item = PyTuple_GetItem(args, i);
-                    if (PyInt_Check(item)) {
-                        val[i] = (float)PyInt_AsLong(item);
-                    } else if (PyFloat_Check(item)) {
-                        val[i] = PyFloat_AsDouble(item);
-                    } else {
-                        PyErr_SetString(PyExc_TypeError, "Vector3D() must take list of floats, or ints");
-                        return NULL;
-                    }
-                }
-                val.setValid();
-                break;
-            default:
-                PyErr_SetString(PyExc_TypeError, "Vector3D must take list of floats, or ints, 3 ints or 3 floats");
-                return NULL;
-                break;
-        }
-            
-        o = newPyVector3D();
-        if ( o == NULL ) {
-                return NULL;
-        }
-        o->coords = val;
-        return (PyObject *)o;
-}
-
-static PyObject * point3d_new(PyObject * self, PyObject * args)
-{
-        PyPoint3D *o;
-        Point3D val;
-        // We need to deal with actual args here
-        PyObject * clist;
-        switch (PyTuple_Size(args)) {
-            case 0:
-                break;
-            case 1:
-                clist = PyTuple_GetItem(args, 0);
-                if ((!PyList_Check(clist)) || (PyList_Size(clist) != 3)) {
-                    PyErr_SetString(PyExc_TypeError, "Point3D() from single value must a list 3 long");
-                    return NULL;
-                }
-                for(int i = 0; i < 3; i++) {
-                    PyObject * item = PyList_GetItem(clist, i);
-                    if (PyInt_Check(item)) {
-                        val[i] = (float)PyInt_AsLong(item);
-                    } else if (PyFloat_Check(item)) {
-                        val[i] = PyFloat_AsDouble(item);
-                    } else if (PyMessageElement_Check(item)) {
-                        PyMessageElement * mitem = (PyMessageElement*)item;
-                        if (!mitem->m_obj->isNum()) {
-                            PyErr_SetString(PyExc_TypeError, "Point3D() must take list of floats, or ints");
-                            return NULL;
-                        }
-                        val[i] = mitem->m_obj->asNum();
-                    } else {
-                        PyErr_SetString(PyExc_TypeError, "Point3D() must take list of floats, or ints");
-                        return NULL;
-                    }
-                }
-                val.setValid();
-                break;
-            case 3:
-                for(int i = 0; i < 3; i++) {
-                    PyObject * item = PyTuple_GetItem(args, i);
-                    if (PyInt_Check(item)) {
-                        val[i] = (float)PyInt_AsLong(item);
-                    } else if (PyFloat_Check(item)) {
-                        val[i] = PyFloat_AsDouble(item);
-                    } else {
-                        PyErr_SetString(PyExc_TypeError, "Point3D() must take list of floats, or ints");
-                        return NULL;
-                    }
-                }
-                val.setValid();
-                break;
-            default:
-                PyErr_SetString(PyExc_TypeError, "Point3D must take list of floats, or ints, 3 ints or 3 floats");
-                return NULL;
-                break;
-        }
-            
-        o = newPyPoint3D();
-        if ( o == NULL ) {
-                return NULL;
-        }
-        o->coords = val;
-        return (PyObject *)o;
-}
-
 static PyObject * bbox_new(PyObject * self, PyObject * args)
 {
     std::vector<float> val;
@@ -828,13 +597,21 @@ static PyObject * quaternion_new(PyObject * self, PyObject * args)
                 {
                 PyObject * v1 = PyTuple_GetItem(args, 0);
                 PyObject * v2 = PyTuple_GetItem(args, 1);
-                if (!PyVector3D_Check(v1) || !PyVector3D_Check(v2)) {
-                    PyErr_SetString(PyExc_TypeError, "Quaternion(a,b) must take two vectors");
+                if (!PyVector3D_Check(v1)) {
+                    PyErr_SetString(PyExc_TypeError, "Quaternion(a,b) must take a vector");
+                    return NULL;
+                }
+                PyVector3D * arg1 = (PyVector3D *)v1;
+                if (PyVector3D_Check(v2)) {
+                    PyVector3D * to = (PyVector3D *)v2;
+                    val = quaternionFromTo(arg1->coords, to->coords);
+                } else if (PyFloat_Check(v2)) {
+                    float angle = PyFloat_AsDouble(v2);
+                    val.rotation(arg1->coords, angle);
+                } else {
+                    PyErr_SetString(PyExc_TypeError, "Quaternion(a,b) must take a vector");
                     return NULL;
                 }
-                PyVector3D * from = (PyVector3D *)v1;
-                PyVector3D * to = (PyVector3D *)v2;
-                val = quaternionFromTo(from->coords, to->coords);
                 }
                 break;
             case 4:
@@ -869,23 +646,6 @@ static PyObject * quaternion_new(PyObject * self, PyObject * args)
         return (PyObject *)o;
 }
 
-static PyObject * worldtime_new(PyObject * self, PyObject * args)
-{
-        PyWorldTime *o;
-                
-        int seconds;
-        if (!PyArg_ParseTuple(args, "i", &seconds)) {
-                return NULL;
-        }
-        o = newPyWorldTime();
-        if ( o == NULL ) {
-                return NULL;
-        }
-        o->time = new WorldTime(seconds);
-        o->own = true;
-        return (PyObject *)o;
-}
-
 static inline void addToOplist(PyOperation * op, PyOplist * o)
 {
     if (op != NULL) {
@@ -1039,46 +799,43 @@ static PyObject * operation_new(PyObject * self, PyObject * args, PyObject * kwd
             return NULL;
         }
     }
-    if (PyMapping_HasKeyString(kwds, "to")) {
-        PyObject * to = PyMapping_GetItemString(kwds, "to");
-        PyObject * to_id = 0;
-        if (PyString_Check(to)) {
-            to_id = to;
-        } else if ((to_id = PyObject_GetAttrString(to, "id")) == NULL) {
-            Py_DECREF(to);
-            PyErr_SetString(PyExc_TypeError, "to is not a string and has no id");
-            return NULL;
-        } else {
-            // to_id == to.getattr("id") and to is finished with
-            Py_DECREF(to);
-        }
-        if (!PyString_Check(to_id)) {
-            Py_DECREF(to_id);
-            PyErr_SetString(PyExc_TypeError, "id of to is not a string");
-            return NULL;
-        }
-        op->operation->setTo(PyString_AsString(to_id));
-        Py_DECREF(to_id);
-    }
-    if (PyMapping_HasKeyString(kwds, "from_")) {
-        PyObject * from = PyMapping_GetItemString(kwds, "from_");
-        PyObject * from_id = 0;
-        if (PyString_Check(from)) {
-            from_id = from;
-        } else if ((from_id = PyObject_GetAttrString(from, "id")) == NULL) {
-            Py_DECREF(from);
-            PyErr_SetString(PyExc_TypeError, "from is not a string and has no id");
-            return NULL;
-        } else {
-            Py_DECREF(from);
-        }
-        if (!PyString_Check(from_id)) {
+    if (kwds != NULL) {
+        PyObject * from = PyDict_GetItemString(kwds, "from_");
+        if (from != NULL) {
+            PyObject * from_id = 0;
+            if (PyString_Check(from)) {
+                from_id = from;
+                Py_INCREF(from_id);
+            } else if ((from_id = PyObject_GetAttrString(from, "id")) == NULL) {
+                PyErr_SetString(PyExc_TypeError, "from is not a string and has no id");
+                return NULL;
+            }
+            if (!PyString_Check(from_id)) {
+                Py_DECREF(from_id);
+                PyErr_SetString(PyExc_TypeError, "id of from is not a string");
+                return NULL;
+            }
+            op->operation->setFrom(PyString_AsString(from_id));
             Py_DECREF(from_id);
-            PyErr_SetString(PyExc_TypeError, "id of from is not a string");
-            return NULL;
         }
-        op->operation->setFrom(PyString_AsString(from_id));
-        Py_DECREF(from_id);
+        PyObject * to = PyDict_GetItemString(kwds, "to");
+        if (to != NULL) {
+            PyObject * to_id = 0;
+            if (PyString_Check(to)) {
+                to_id = to;
+                Py_INCREF(to_id);
+            } else if ((to_id = PyObject_GetAttrString(to, "id")) == NULL) {
+                PyErr_SetString(PyExc_TypeError, "to is not a string and has no id");
+                return NULL;
+            }
+            if (!PyString_Check(to_id)) {
+                Py_DECREF(to_id);
+                PyErr_SetString(PyExc_TypeError, "id of to is not a string");
+                return NULL;
+            }
+            op->operation->setTo(PyString_AsString(to_id));
+            Py_DECREF(to_id);
+        }
     }
     std::vector<Root> & args_list = op->operation->modifyArgs();
     addToArgs(args_list, arg1);
@@ -1087,9 +844,15 @@ static PyObject * operation_new(PyObject * self, PyObject * args, PyObject * kwd
     return (PyObject *)op;
 }
 
+// In Python 2.3 or later this it is okay to pass in null for the methods
+// of a module, making this obsolete.
+static PyMethodDef no_methods[] = {
+    {NULL,          NULL}                       /* Sentinel */
+};
+
 static PyMethodDef atlas_methods[] = {
     {"Operation",  (PyCFunction)operation_new,  METH_VARARGS|METH_KEYWORDS},
-    {"isLocation", is_location,                 METH_VARARGS},
+    {"isLocation", is_location,                 METH_O},
     {"Location",   location_new,                METH_VARARGS},
     {"Entity",     (PyCFunction)entity_new,     METH_VARARGS|METH_KEYWORDS},
     {"Message",    oplist_new,                  METH_VARARGS},
@@ -1104,16 +867,6 @@ static PyMethodDef physics_methods[] = {
     {NULL,          NULL}                       /* Sentinel */
 };
 
-static PyMethodDef vector3d_methods[] = {
-    {"Vector3D",    vector3d_new,               METH_VARARGS},
-    {NULL,          NULL}                       /* Sentinel */
-};
-
-static PyMethodDef point3d_methods[] = {
-    {"Point3D",     point3d_new,                 METH_VARARGS},
-    {NULL,          NULL}                       /* Sentinel */
-};
-
 static PyMethodDef bbox_methods[] = {
     {"BBox",        bbox_new,                 METH_VARARGS},
     {NULL,          NULL}                       /* Sentinel */
@@ -1124,11 +877,6 @@ static PyMethodDef quaternion_methods[] = {
     {NULL,          NULL}                       /* Sentinel */
 };
 
-static PyMethodDef server_methods[] = {
-    {"WorldTime",   worldtime_new,              METH_VARARGS},
-    {NULL,          NULL}                       /* Sentinel */
-};
-
 static PyMethodDef common_methods[] = {
     //{"null",      null_new,                   METH_VARARGS},
     {NULL,          NULL}                       /* Sentinel */
@@ -1194,16 +942,6 @@ void init_python_api()
         return;
     }
 
-    if (Py_InitModule("Vector3D", vector3d_methods) == NULL) {
-        log(CRITICAL, "Python init failed to create Vector3D module\n");
-        return;
-    }
-
-    if (Py_InitModule("Point3D", point3d_methods) == NULL) {
-        log(CRITICAL, "Python init failed to create Point3D module\n");
-        return;
-    }
-
     if (Py_InitModule("BBox", bbox_methods) == NULL) {
         log(CRITICAL, "Python init failed to create BBox module\n");
         return;
@@ -1280,21 +1018,54 @@ void init_python_api()
     Py_DECREF(o);
     Py_DECREF(globals);
 
-    PyObject * server;
-    if ((server = Py_InitModule("server", server_methods)) == NULL) {
-        log(CRITICAL, "Python init failed to create server module\n");
+    PyObject * server = Py_InitModule("server", no_methods);
+    if (server == NULL) {
+        log(CRITICAL, "Python init failed to create server module");
         return;
     }
-    PyObject * server_dict = PyModule_GetDict(server);
-    PyObject * dictlist = PyModule_New("dictlist");
-    PyObject * add_value = (PyObject *)PyObject_NEW(FunctionObject, &dictlist_add_value_type);
-    PyObject_SetAttrString(dictlist, "add_value", add_value);
-    Py_DECREF(add_value);
-    PyObject * remove_value = (PyObject *)PyObject_NEW(FunctionObject, &dictlist_remove_value_type);
-    PyObject_SetAttrString(dictlist, "remove_value", remove_value);
-    Py_DECREF(remove_value);
-    PyDict_SetItemString(server_dict, "dictlist", dictlist);
-    Py_DECREF(dictlist);
+    
+    // New module code
+    // PyWorldTime_Type.tp_new = PyType_GenericNew;
+    if (PyType_Ready(&PyWorldTime_Type) < 0) {
+        log(CRITICAL, "Python init failed to ready WorldTime wrapper type");
+        return;
+    }
+    PyModule_AddObject(server, "WorldTime", (PyObject *)&PyWorldTime_Type);
+
+    PyObject * rules = Py_InitModule("rulesets", no_methods);
+    if (rules == NULL) {
+        log(CRITICAL, "Python init failed to create rules module");
+        return;
+    }
+    if (PyType_Ready(&PyStatistics_Type) < 0) {
+        log(CRITICAL, "Python init failed to ready Statistics wrapper type");
+        return;
+    }
+    PyModule_AddObject(rules, "Statistics", (PyObject *)&PyStatistics_Type);
+
+    PyObject * point3d = Py_InitModule("Point3D", no_methods);
+    if (point3d == NULL) {
+        log(CRITICAL, "Python init failed to create Point3D module\n");
+        return;
+    }
+    // PyPoint3D_Type.tp_new = PyType_GenericNew;
+    if (PyType_Ready(&PyPoint3D_Type) < 0) {
+        log(CRITICAL, "Python init failed to ready Point3D wrapper type");
+        return;
+    }
+    PyModule_AddObject(point3d, "Point3D", (PyObject *)&PyPoint3D_Type);
+
+    PyObject * vector3d = Py_InitModule("Vector3D", no_methods);
+    if (vector3d == NULL) {
+        log(CRITICAL, "Python init failed to create Vector3D module\n");
+        return;
+    }
+    // PyVector3D_Type.tp_new = PyType_GenericNew;
+    if (PyType_Ready(&PyVector3D_Type) < 0) {
+        log(CRITICAL, "Python init failed to ready Vector3D wrapper type");
+        return;
+    }
+    PyModule_AddObject(vector3d, "Vector3D", (PyObject *)&PyVector3D_Type);
 
     PyRun_SimpleString("from hooks import ruleset_import_hooks\n");
     PyRun_SimpleString((char *)importCmd.c_str());
