@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef RULESETS_STATISTICS_H
 #define RULESETS_STATISTICS_H
@@ -8,6 +21,7 @@
 #include "common/types.h"
 
 class Character;
+class ArithmeticScript;
 
 /// \brief This class handles presentation of a characters statistics.
 ///
@@ -20,6 +34,8 @@ class Character;
 class Statistics {
   public:
     typedef std::map<std::string, float> SkillDict;
+
+    ArithmeticScript * m_script;
   protected:
     Character & m_character;
 
@@ -28,12 +44,11 @@ class Statistics {
   public:
     Statistics(Character & chr);
 
-    /// \brief Maximum weight character can lift
-    float strength();
-    /// \brief Attack power
-    float attack();
-    /// \brief Defence power
-    float defence();
+    // Get the value for a names statistic
+    float get(const std::string & name);
+
+    // Return a default value for a statistic not supported by this model
+    float get_default(const std::string & name);
 
     /// \brief Increment the characters skill in a certain area
     void increment(const std::string & name, OpVector & res);
