@@ -21,7 +21,7 @@ from mind.Knowledge import Knowledge
 from mind.panlingua import interlinguish,ontology
 from mind.compass import vector_to_compass
 from common import log,const
-from server import dictlist
+import dictlist
 import mind.goals
 import mind.goals.common
 
@@ -52,7 +52,6 @@ class NPCMind(BaseMind):
         #???self.debug=debug(self.name+".mind.log")
         self.tick_count=0
         self.message_queue=None
-        self.time=WorldTime(31104000)
         #This is going to be really tricky
         self.map.add_hooks_append("add_map")
         self.map.update_hooks_append("update_map")
