@@ -411,30 +411,28 @@ class hunt(Goal):
 ##################### DEFEND (SPOT SOMETHING, THEN KILL IT) ###################
 
 class defend(Goal):
-    def __init__(self, me, with, what, range):
+    def __init__(self, what, range):
         Goal.__init__(self, "defend against something",
-                      self.none_in_range,
-                      [spot_something(what, range),
-                       acquire_thing(me, with),
+                      self.none_in_sight,
+                      [spot_something(what),
                        hunt_for(what, range),
                        self.fight])
-        self.with=with
         self.what=what
         self.range=range
-        self.square_range=range*range
-        self.vars=["with", "what", "range"]
-    def none_in_range(self, me):
+        self.vars=["what", "range"]
+    def none_in_sight(self, me):
+        target_id=me.get_knowledge('focus', self.what)
+        if target_id:
+            return 0
         thing_all=me.map.find_by_type(self.what)
-        for thing in thing_all:
-            if square_distance(me.location, thing.location) < self.square_range:
-                return 0
+        if thing_all and len(thing_all) > 0:
+            return 0
         return 1
     def fight(self, me):
-        if me.things.has_key(self.with)==0: return
-        weapon=me.find_thing(self.with)[0]
-        if me.things.has_key(self.what)==0: return
-        enemy=me.find_thing(self.what)[0]
-        return Operation("cut",Entity(weapon.id),Entity(enemy.id),to=weapon)
+        target_id=me.get_knowledge('focus', self.what)
+        if not target_id:
+            return
+        return Operation("attack",Entity(target_id))
 
 ############################ BUY SOMETHING (AS TRADER) ########################
 
@@ -643,6 +641,8 @@ class transaction(Goal):
         for item in me.money_transfers:
             if item[0]==self.who:
                 payed=payed+int(item[1])
+        for item in me.money_transfers:
+            if item[0]==self.who:
                 me.money_transfers.remove(item)
         if payed != self.payed:
             self.payed=payed
@@ -671,12 +671,16 @@ class hireling_transaction(transaction):
         if employer:
             print 'Already employed by ' + employer
             return Operation("talk",Entity(say="Sorry, I am currently working for someone else."))
+        who=me.map.get(self.who)
+        if not who:
+            print "Who am I talking to"
+            return
         if self.payed < self.cost:
-            return Operation("talk",Entity(say=self.who.name+" you owe me "+str(self.cost-self.payed)+" coins."))
+            return Operation("talk",Entity(say=who.name+" you owe me "+str(self.cost-self.payed)+" coins."))
         res=Message()
-        me.add_knowledge('employer', me.id, self.who.id)
+        me.add_knowledge('employer', me.id, who.id)
         # FIXME add the new goal
-        goal = accompany(self.who.id)
+        goal = accompany(who.id)
         me.goals.insert(0,goal)
         res.append(Operation("talk",Entity(say="I will help you out until sundown today.")))
         self.irrelevant=1
