@@ -13,6 +13,7 @@ from editor import editor
 from Quaternion import Quaternion
 from Vector3D import Vector3D
 import time
+from math import *
 
 #goal priority
 #1) eating: certain times
@@ -34,6 +35,7 @@ graveyard_height=0
 hall_xyz=(5,3,settlement_height)
 forest_xyz=(-20,-60,settlement_height)
 
+village_xyz=(150,150,22)
 pig_sty_xyz=(8,8,settlement_height)
 butcher_stall_xyz=(155,140,settlement_height)
 butcher_xyz=(153,142,settlement_height)
@@ -41,6 +43,8 @@ tool_stall_xyz=(150,138,settlement_height)
 tool_merchant_xyz=(150,140,settlement_height)
 mausoleum_xyz=(-160, 105, graveyard_height)
 
+camp_xyz=(100,-50,22)
+
 lake_xyz=(-40,-70,0)
 
 knowledge=[('axe','place','smithy'),
@@ -193,7 +197,32 @@ def default(mapeditor):
     points['0x1'] = [0, 1, 14.2]
     points['1x1'] = [1, 1, 19.7]
 
-    m.set(world.id, terrain={'points' : points}, name="moraf")
+    minx=0
+    miny=0
+    minz=0
+    maxx=0
+    maxy=0
+    maxz=0
+    for i in points.values():
+        x = i[0]
+        y = i[1]
+        z = i[2]
+        if not minx or x < minx:
+            minx = x
+        if not miny or y < miny:
+            miny = y
+        if not minz or z < minz:
+            minz = z
+        if not maxx or x > maxx:
+            maxx = x
+        if not maxy or y > maxy:
+            maxy = y
+        if not maxz or z > maxz:
+            maxz = z
+        
+    # print minx, ":", miny, ":", minz, ":", maxx, ":", maxy, ":", maxz
+
+    m.set(world.id, terrain={'points' : points}, name="moraf", bbox=[minx, miny, minz, maxx, maxy, maxz])
 
 # a wall around the world
 
@@ -454,6 +483,33 @@ def default(mapeditor):
     m.learn(warriors,(il.lunch,"meal(self, 'ham','midday', 'inn')"))
     m.learn(warriors,(il.sup,"meal(self, 'beer', 'evening', 'inn')"))
 
+    # Goblins
+
+    cfire=m.make('campfire',type='campfire',xyz=(100,-50,settlement_height))
+    m.make('fire',type='fire',xyz=(0,0,0),parent=cfire.id)
+
+    cfire=m.make('campfire',type='campfire',xyz=(90,-50,settlement_height))
+    m.make('fire',type='fire',xyz=(0,0,0),parent=cfire.id)
+
+    for i in range(10, 350, 5):
+        direction=Vector3D(sin(radians(i)) * uniform(0,2), cos(radians(i)) * uniform(0,2), 10).unit_vector()
+        orient=Quaternion(Vector3D(0,0,1), direction)
+        m.make('stake',type='stake',xyz=(100 + 14 * sin(radians(i)), -50 + 16 * cos(radians(i)), -1), bbox=[-0.5,-0.5,0,0.5,0.5,5 + uniform(0,2)], orientation=orient.as_list(), mass=2000, mode="relative")
+        
+    camp_area_points=[]
+    for i in range(10, 350, 17):
+        camp_area_points.append([14 * sin(radians(i)), 16 * cos(radians(i))])
+    camp_area={'points': camp_area_points, 'layer':7 }
+    m.make('camp_area', xyz=camp_xyz, type='path', area=camp_area, bbox=[-14, -16, 0, 14, 16, 1])
+
+    goblin_guards=[]
+    goblin=m.make('goblin', type='goblin', xyz=(102, -33, settlement_height))
+    goblin_guards.append(goblin)
+    goblin=m.make('goblin', type='goblin', xyz=(98, -33, settlement_height))
+    goblin_guards.append(goblin)
+
+    m.learn(goblin_guards,(il.defend,"defend('settler', 10)"))
+
     deers=[]
     xbase = uniform(-180,180)
     ybase = uniform(-180,180)
@@ -687,3 +743,23 @@ def test_own(mapeditor):
     settler=m.make('settler',xyz=(1,1,0), sex='male')
     axe=m.make('axe',type='axe',xyz=(0,0,0),parent=settler.id)
     m.own(settler,axe)
+
+
+def test_goblins(mapeditor):
+
+    m=editor(mapeditor)
+    goblin_guards=[]
+    goblin=m.make('goblin', type='goblin', xyz=(102, -33, settlement_height))
+    goblin_guards.append(goblin)
+    goblin=m.make('goblin', type='goblin', xyz=(98, -33, settlement_height))
+    goblin_guards.append(goblin)
+
+    m.learn(goblin_guards,(il.defend,"defend('settler', 10)"))
+
+def test_deer(mapeditor):
+
+    m=editor(mapeditor)
+
+    d=m.make('deer', type='deer', xyz=(5, 0, settlement_height))
+    m.learn(d,deer_goals)
+    # m.make('settler', type='settler', xyz=(0, 0, settlement_height))
