@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Account.h"
 
@@ -17,6 +30,7 @@
 #include "common/const.h"
 #include "common/debug.h"
 #include "common/serialno.h"
+#include "common/inheritance.h"
 #include "common/compose.hpp"
 
 #include <wfmath/atlasconv.h>
@@ -24,8 +38,8 @@
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
 
-#include <sigc++/bind.h>
-#include <sigc++/object_slot.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/functors/mem_fun.h>
 
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
@@ -52,22 +66,11 @@ Account::Account(Connection * conn, const std::string & uname,
 
 Account::~Account()
 {
-    ConMap::const_iterator J = m_destroyedConnections.begin();
-    ConMap::const_iterator Jend = m_destroyedConnections.end();
-    for (; J != Jend; ++J) {
-        J->second->disconnect();
-        delete J->second;
-    }
 }
 
 void Account::characterDestroyed(long id)
 {
     m_charactersDict.erase(id);
-    ConMap::iterator I = m_destroyedConnections.find(id);
-    if (I != m_destroyedConnections.end()) {
-        delete I->second;
-        m_destroyedConnections.erase(I);
-    }
     if (consts::enable_persistence) {
         Persistance::instance()->delCharacter(String::compose("%1", id));
     }
@@ -80,8 +83,7 @@ void Account::addCharacter(Entity * chr)
         return;
     }
     m_charactersDict[chr->getIntId()] = chr;
-    SigC::Connection * con = new SigC::Connection(chr->destroyed.connect(SigC::bind<long>(SigC::slot(*this, &Account::characterDestroyed), chr->getIntId())));
-    m_destroyedConnections[chr->getIntId()] = con;
+    chr->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Account::characterDestroyed), chr->getIntId()));
 }
 
 Entity * Account::addNewCharacter(const std::string & typestr,
@@ -106,8 +108,7 @@ Entity * Account::addNewCharacter(const std::string & typestr,
         // if a normal entity gets into the account, and connection, it
         // starts getting hard to tell whether or not they exist.
         m_charactersDict[chr->getIntId()] = chr;
-        SigC::Connection * con = new SigC::Connection(chr->destroyed.connect(SigC::bind<long>(SigC::slot(*this, &Account::characterDestroyed), chr->getIntId())));
-        m_destroyedConnections[chr->getIntId()] = con;
+        chr->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Account::characterDestroyed), chr->getIntId()));
         m_connection->addObject(chr);
         if (consts::enable_persistence) {
             Persistance::instance()->addCharacter(*this, *chr);
@@ -126,17 +127,18 @@ Entity * Account::addNewCharacter(const std::string & typestr,
     for(int i = 0; i < 10; i++) {
         Create c;
         c->setTo(chr->getId());
-        c->setSerialno(newSerialNo());
         c->setArgs1(create_arg);
         world.message(c, *chr);
     }
 
+    logEvent(TAKE_CHAR, String::compose("%1 %2 %3 Created character %4(%5) by account %6", m_connection->getId(), getId(), chr->getId(), chr->getName(), chr->getType(), m_username).c_str());
+
     return chr;
 }
 
 void Account::LogoutOperation(const Operation & op, OpVector &)
 {
-    debug(std::cout << "Account logout: " << getId() << std::endl;);
+    std::cout << "Account logout: " << getId() << std::endl;
 
     // It is possible this account is being forcibly logged out at a time
     // when it is not logged in.
@@ -146,8 +148,9 @@ void Account::LogoutOperation(const Operation & op, OpVector &)
 
     Info info;
     info->setArgs1(op);
-    info->setRefno(op->getSerialno());
-    info->setSerialno(newSerialNo());
+    if (!op->isDefaultSerialno()) {
+        info->setRefno(op->getSerialno());
+    }
     info->setFrom(getId());
     info->setTo(getId());
     // FIXME Direct send rather than reply - requires local refno handling
@@ -211,17 +214,39 @@ void Account::CreateOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    if (characterError(op, arg, res)) {
+    if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
+        error(op, "Entity has no type", res, getId());
         return;
     }
 
-    if (!arg->hasAttrFlag(Atlas::Objects::PARENTS_FLAG) ||
-        arg->getParents().empty()) {
-        error(op, "Character has no type", res, getId());
+    const std::list<std::string> & parents = arg->getParents();
+    if (parents.empty()) {
+        error(op, "Entity has empty type list.", res, getId());
         return;
     }
     
-    const std::string & typestr = arg->getParents().front();
+#if 0
+    const std::string & typestr = parents.front();
+
+    if (characterError(op, arg, res)) {
+        return;
+    }
+#else
+    // Interim fix because of weird client interface
+    std::string typestr = parents.front();
+    
+    if (characterError(op, arg, res)) {
+        if (typestr == "__bad__type__") {
+            return;
+        }
+        res.clear();
+        if (!Inheritance::instance().hasClass(typestr)) {
+            Inheritance::instance().addChild(atlasClass(typestr, "settler"));
+        }
+        typestr = "settler";
+    }
+#endif
+
     debug( std::cout << "Account creating a " << typestr << " object"
                      << std::endl << std::flush; );
 
@@ -236,9 +261,14 @@ void Account::CreateOperation(const Operation & op, OpVector & res)
     Anonymous info_arg;
     obj->addToEntity(info_arg);
     info->setArgs1(info_arg);
-    info->setSerialno(newSerialNo());
-
     res.push_back(info);
+
+    Sight sight;
+    sight->setTo(getId());
+    Anonymous sight_arg;
+    addToEntity(sight_arg);
+    sight->setArgs1(sight_arg);
+    res.push_back(sight);
 }
 
 void Account::SetOperation(const Operation & op, OpVector & res)
@@ -262,7 +292,9 @@ void Account::SetOperation(const Operation & op, OpVector & res)
 
     EntityDict::const_iterator J = m_charactersDict.find(intId);
     if (J == m_charactersDict.end()) {
-        return error(op, "Set character for unknown character", res, getId());
+        // Client has sent a Set op for an object that is not
+        // one of our characters.
+        return error(op, "Permission denied.", res, getId());
     }
 
     Entity * e = J->second;
@@ -317,9 +349,10 @@ void Account::ImaginaryOperation(const Operation & op, OpVector & res)
     Sight s;
     s->setArgs1(op);
     s->setFrom(getId());
-    s->setSerialno(newSerialNo());
-    // FIXME Remove this
-    s->setRefno(op->getSerialno());
+    // FIXME Remove this - broadcasting
+    if (!op->isDefaultSerialno()) {
+        s->setRefno(op->getSerialno());
+    }
     RootEntity arg = smart_dynamic_cast<RootEntity>(args.front());
 
     if (!arg.isValid()) {
@@ -346,9 +379,10 @@ void Account::TalkOperation(const Operation & op, OpVector & res)
     Sound s;
     s->setArgs1(op);
     s->setFrom(getId());
-    s->setSerialno(newSerialNo());
-    // FIXME Remove this - no really
-    s->setRefno(op->getSerialno());
+    // FIXME Remove this - broadcasting
+    if (!op->isDefaultSerialno()) {
+        s->setRefno(op->getSerialno());
+    }
     RootEntity arg = smart_dynamic_cast<RootEntity>(args.front());
 
     if (!arg.isValid()) {
@@ -375,7 +409,6 @@ void Account::LookOperation(const Operation & op, OpVector & res)
         Anonymous sight_arg;
         m_connection->m_server.m_lobby.addToEntity(sight_arg);
         s->setArgs1(sight_arg);
-        s->setSerialno(newSerialNo());
         res.push_back(s);
         return;
     }
@@ -395,7 +428,6 @@ void Account::LookOperation(const Operation & op, OpVector & res)
         Anonymous sight_arg;
         J->second->addToEntity(sight_arg);
         s->setArgs1(sight_arg);
-        s->setSerialno(newSerialNo());
         res.push_back(s);
         return;
     }
@@ -407,7 +439,6 @@ void Account::LookOperation(const Operation & op, OpVector & res)
         Anonymous sight_arg;
         K->second->addToEntity(sight_arg);
         s->setArgs1(sight_arg);
-        s->setSerialno(newSerialNo());
         res.push_back(s);
         return;
     }
