@@ -1,14 +1,25 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef SERVER_ACCOUNT_H
 #define SERVER_ACCOUNT_H
 
 #include "common/OOGThing.h"
 
-#include <sigc++/connection.h>
-
 class Connection;
 
 /// \brief This is the base class for storing information about uses who
@@ -19,10 +30,7 @@ class Connection;
 /// characterError().
 class Account : public OOGThing {
   protected:
-    typedef std::map<long, SigC::Connection *> ConMap;
-
     EntityDict m_charactersDict;
-    ConMap m_destroyedConnections;
 
     Entity * addNewCharacter(const std::string &,
                              const Atlas::Objects::Entity::RootEntity &);
