@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "CommListener.h"
 
@@ -63,6 +76,8 @@ int CommListener::setup(int port)
     if (!m_listener.is_open()) {
         return -1;
     }
+    // Set a linger time of 0 seconds, so that the socket is got rid
+    // of quickly.
     int socket = m_listener.getSocket();
     struct linger {
         int   l_onoff;
@@ -70,7 +85,7 @@ int CommListener::setup(int port)
     } listenLinger = { 1, 0 };
     ::setsockopt(socket, SOL_SOCKET, SO_LINGER, &listenLinger,
                                                 sizeof(listenLinger));
-
+    // Ensure the address can be reused once we are done with it.
     int flag = 1;
     ::setsockopt(socket, SOL_SOCKET, SO_REUSEADDR, &flag, sizeof(flag));
     return 0;
@@ -112,15 +127,17 @@ int CommListener::accept()
         address = "unknown";
     }
     
-    create(asockfd, address);
-    return 0;
+    return create(asockfd, address);
 }
 
-void CommListener::create(int asockfd, const char * address)
+int CommListener::create(int asockfd, const char * address)
 {
     std::string connection_id;
-    newId(connection_id);
-    assert(!connection_id.empty());
+    if (newId(connection_id) < 0) {
+        log(ERROR, "Unable to accept connection as no ID available");
+        close(asockfd);
+        return -1;
+    }
 
     CommRemoteClient * newcli = new CommRemoteClient(m_commServer, asockfd,
                                                      address, connection_id);
@@ -130,4 +147,6 @@ void CommListener::create(int asockfd, const char * address)
     // Add this new client to the list.
     m_commServer.addSocket(newcli);
     m_commServer.addIdle(newcli);
+
+    return 0;
 }
