@@ -1,12 +1,29 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2003 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2003-2004,2006 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "CommPSQLSocket.h"
 
+#include "IdlePSQLConnector.h"
+#include "CommServer.h"
+
 #include "common/Database.h"
 #include "common/log.h"
 #include "common/debug.h"
+#include "common/globals.h"
 
 #include <iostream>
 
@@ -35,6 +52,12 @@ CommPSQLSocket::CommPSQLSocket(CommServer & svr, Database & db) :
 
 CommPSQLSocket::~CommPSQLSocket()
 {
+    if (!exit_flag) {
+        m_db.shutdownConnection();
+
+        IdlePSQLConnector * ipsqlc = new IdlePSQLConnector(m_idleManager, m_db);
+        m_idleManager.addIdle(ipsqlc);
+    }
 }
 
 int CommPSQLSocket::getFd() const
@@ -48,7 +71,7 @@ int CommPSQLSocket::getFd() const
 bool CommPSQLSocket::eof()
 {
     debug(std::cout << "CommPSQLSocket::eof()" << std::endl << std::flush;);
-    return false;
+    return PQstatus(m_db.getConnection()) != CONNECTION_OK;
 }
 
 bool CommPSQLSocket::isOpen() const
