@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000,2001 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2000-2006 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Connection.h"
 
@@ -27,8 +40,8 @@
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
 
-#include <sigc++/bind.h>
-#include <sigc++/object_slot.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/functors/mem_fun.h>
 
 #include <cassert>
 
@@ -48,6 +61,7 @@ Connection::Connection(CommClient & client,
                                               m_server(svr)
 {
     m_server.incClients();
+    logEvent(CONNECT, String::compose("%1 - - Connect from %2", id, addr).c_str());
 }
 
 Connection::~Connection()
@@ -56,21 +70,18 @@ Connection::~Connection()
     // of objects when we delete it.
     assert(!m_obsolete);
     m_obsolete = true;
-    ConMap::const_iterator J = m_destroyedConnections.begin();
-    ConMap::const_iterator Jend = m_destroyedConnections.end();
-    for (; J != Jend; ++J) {
-        J->second->disconnect();
-        delete J->second;
-    }
 
     debug(std::cout << "destroy called" << std::endl << std::flush;);
     
+    logEvent(DISCONNECT, String::compose("%1 - - Disconnect", getId()).c_str());
+
     BaseDict::const_iterator Iend = m_objects.end();
     for (BaseDict::const_iterator I = m_objects.begin(); I != Iend; ++I) {
         Account * ac = dynamic_cast<Account *>(I->second);
         if (ac != NULL) {
             m_server.m_lobby.delAccount(ac);
             ac->m_connection = NULL;
+            logEvent(LOGOUT, String::compose("%1 %2 - Disconnect account %3", getId(), ac->getId(), ac->m_username).c_str());
             continue;
         }
         Character * character = dynamic_cast<Character *>(I->second);
@@ -78,6 +89,7 @@ Connection::~Connection()
             if (character->m_externalMind != NULL) {
                 delete character->m_externalMind;
                 character->m_externalMind = NULL;
+                logEvent(DROP_CHAR, String::compose("%1 - %2 Disconnect character %3(%4)", getId(), character->getId(), character->getName(), character->getType()).c_str());
             }
         }
     }
@@ -98,7 +110,10 @@ Account * Connection::addPlayer(const std::string& username,
     std::string newAccountId;
 
     long intId = newId(newAccountId);
-    assert(!newAccountId.empty());
+    if (intId < 0) {
+        log(ERROR, "Account creation failed as no ID available");
+        return 0;
+    }
 
     Player * player = new Player(this, username, hash, newAccountId, intId);
     addObject(player);
@@ -112,19 +127,13 @@ Account * Connection::addPlayer(const std::string& username,
 void Connection::addObject(BaseEntity * obj)
 {
     m_objects[obj->getIntId()] = obj;
-    SigC::Connection * con = new SigC::Connection(obj->destroyed.connect(SigC::bind<long>(SigC::slot(*this, &Connection::objectDeleted), obj->getIntId())));
-    m_destroyedConnections[obj->getIntId()] = con;
+    obj->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Connection::objectDeleted), obj->getIntId()));
 }
 
 void Connection::removeObject(long id)
 {
     if (!m_obsolete) {
         m_objects.erase(id);
-        ConMap::iterator I = m_destroyedConnections.find(id);
-        if (I != m_destroyedConnections.end()) {
-            delete I->second;
-            m_destroyedConnections.erase(I);
-        }
     }
 }
 
@@ -157,40 +166,36 @@ void Connection::operation(const Operation & op, OpVector & res)
         debug(std::cout << "deliver locally" << std::endl << std::flush;);
         callOperation(op, res);
         return;
-    } else {
-        const std::string & from = op->getFrom();
-        debug(std::cout << "send on to " << from << std::endl << std::flush;);
-        BaseDict::const_iterator I = m_objects.find(integerId(from));
-        if (I == m_objects.end()) {
-            error(op, String::compose("Client \"%1\" op from \"%2\" is from non-existant object.", op->getParents().front(), from).c_str(), res);
-            return;
-        }
-        BaseEntity * b_ent = I->second;
-        Entity * ig_ent = dynamic_cast<Character *>(b_ent);
-        if (ig_ent == NULL) {
-            b_ent->operation(op, res);
-            return;
-        }
-        Character * character = dynamic_cast<Character *>(b_ent);
-        if ((character != NULL) && (character->m_externalMind == NULL)) {
-            character->m_externalMind = new ExternalMind(*this,
-                                                         character->getId(),
-                                                         character->getIntId());
-            debug(std::cout << "Subscribing existing character" << std::endl
-                            << std::flush;);
-            Info info;
-            Anonymous info_arg;
-            character->addToEntity(info_arg);
-            info->setArgs1(info_arg);
-            info->setSerialno(newSerialNo());
-
-            res.push_back(info);
-            character->externalOperation(op);
-            return;
-        }
-        ig_ent->externalOperation(op);
+    }
+    const std::string & from = op->getFrom();
+    debug(std::cout << "send on to " << from << std::endl << std::flush;);
+    BaseDict::const_iterator I = m_objects.find(integerId(from));
+    if (I == m_objects.end()) {
+        error(op, String::compose("Client \"%1\" op from \"%2\" is from non-existant object.", op->getParents().front(), from).c_str(), res);
         return;
     }
+    BaseEntity * b_ent = I->second;
+    Entity * ig_ent = dynamic_cast<Entity *>(b_ent);
+    if (ig_ent == NULL) {
+        b_ent->operation(op, res);
+        return;
+    }
+    Character * character = dynamic_cast<Character *>(b_ent);
+    if ((character != NULL) && (character->m_externalMind == NULL)) {
+        debug(std::cout << "Subscribing existing character" << std::endl
+                        << std::flush;);
+        character->m_externalMind = new ExternalMind(*this, character->getId(),
+                                                     character->getIntId());
+        Info info;
+        Anonymous info_arg;
+        character->addToEntity(info_arg);
+        info->setArgs1(info_arg);
+
+        res.push_back(info);
+
+        logEvent(TAKE_CHAR, String::compose("%1 - %2 Taken character %3(%4)", getId(), ig_ent->getId(), ig_ent->getName(), ig_ent->getType()).c_str());
+    }
+    ig_ent->externalOperation(op);
 }
 
 void Connection::LoginOperation(const Operation & op, OpVector & res)
@@ -261,9 +266,10 @@ void Connection::LoginOperation(const Operation & op, OpVector & res)
     Anonymous info_arg;
     player->addToEntity(info_arg);
     info->setArgs1(info_arg);
-    info->setSerialno(newSerialNo());
     debug(std::cout << "Good login" << std::endl << std::flush;);
     res.push_back(info);
+
+    logEvent(LOGIN, String::compose("%1 %2 - Login account %3", getId(), player->getId(), username).c_str());
 }
 
 void Connection::CreateOperation(const Operation & op, OpVector & res)
@@ -313,6 +319,10 @@ void Connection::CreateOperation(const Operation & op, OpVector & res)
         return;
     }
     Account * player = addPlayer(username, password);
+    if (player == 0) {
+        clientError(op, "Account creation failed", res);
+        return;
+    }
     if (consts::enable_database) {
         Persistance::instance()->putAccount(*player);
     }
@@ -320,9 +330,10 @@ void Connection::CreateOperation(const Operation & op, OpVector & res)
     Anonymous info_arg;
     player->addToEntity(info_arg);
     info->setArgs1(info_arg);
-    info->setSerialno(newSerialNo());
     debug(std::cout << "Good create" << std::endl << std::flush;);
     res.push_back(info);
+
+    logEvent(LOGIN, String::compose("%1 %2 - Create account %3", getId(), player->getId(), username).c_str());
 }
 
 void Connection::LogoutOperation(const Operation & op, OpVector & res)
@@ -332,8 +343,9 @@ void Connection::LogoutOperation(const Operation & op, OpVector & res)
         // Logging self out
         Info info;
         info->setArgs1(op);
-        info->setRefno(op->getSerialno());
-        info->setSerialno(newSerialNo());
+        if (!op->isDefaultSerialno()) {
+            info->setRefno(op->getSerialno());
+        }
         // FIXME Direct call of send. Need local refno handling.
         send(info);
         disconnect();
@@ -341,36 +353,46 @@ void Connection::LogoutOperation(const Operation & op, OpVector & res)
     }
     const Root & arg = args.front();
     
-    Element user_attr;
-    if (arg->copyAttr("username", user_attr) != 0 || !user_attr.isString()) {
-        error(op, "Got Logout with no username.", res);
+    if (!arg->hasAttrFlag(Atlas::Objects::ID_FLAG)) {
+        error(op, "Got logout for entith with no ID", res);
         return;
     }
-    const std::string & username = user_attr.String();
-
-    Element passwd_attr;
-    if (arg->copyAttr("password", passwd_attr) != 0 || !passwd_attr.isString()) {
-        error(op, "No account password given", res);
+    const long obj_id = integerId(arg->getId());
+    if (obj_id == -1) {
+        error(op, "Got logout for non numeric entity ID", res);
         return;
     }
-    const std::string & password = passwd_attr.String();
-    Account * player = m_server.getAccountByName(username);
-    if ((!player) || (password != player->m_password)) {
-        error(op, "Logout failed", res);
+    BaseDict::iterator I = m_objects.find(obj_id);
+    if (I == m_objects.end()) {
+        error(op, "Got logout for unknown entity ID", res);
         return;
     }
+    // This is very similar code to stuff that does the same job in
+    // Connection destructor. Should be possible to share some, but
+    // the log messages should probably be different.
+    Account * ac = dynamic_cast<Account *>(I->second);
+    Character * character = dynamic_cast<Character *>(I->second);
+    if (ac != 0) {
+        m_server.m_lobby.delAccount(ac);
+        ac->m_connection = 0;
+        m_objects.erase(I);
+        // FIXME Remove all characters associated with this account.
+        logEvent(LOGOUT, String::compose("%1 %2 - Logout account %3", getId(), ac->getId(), ac->m_username).c_str());
+    }
+    if (character != 0) {
+        assert(character->m_externalMind != 0);
+        delete character->m_externalMind;
+        character->m_externalMind = 0;
+        logEvent(DROP_CHAR, String::compose("%1 - %2 Logout character %3(%4)", getId(), character->getId(), character->getName(), character->getType()).c_str());
 
-    // FIXME This won't work. This connection won't have the account ID
-    // so won't be able to find it. If it did, then it could just log out
-    // the normal way. Pointless.
-    Operation l(op.copy());
-    l->setFrom(player->getId());
+    }
 
-    OpVector tres;
-    operation(l, tres);
-    // Its not safe to assert this. FIXME Look into what might be returned
-    // in the way of errors, and where they should go.
-    assert(tres.empty());
+    Info info;
+    info->setArgs1(op);
+    if (!op->isDefaultSerialno()) {
+        info->setRefno(op->getSerialno());
+    }
+    res.push_back(info);
 }
 
 void Connection::GetOperation(const Operation & op, OpVector & res)
@@ -382,7 +404,6 @@ void Connection::GetOperation(const Operation & op, OpVector & res)
         Anonymous info_arg;
         m_server.addToEntity(info_arg);
         info->setArgs1(info_arg);
-        info->setSerialno(newSerialNo());
         debug(std::cout << "Replying to empty get" << std::endl << std::flush;);
     } else {
         const Root & arg = args.front();
@@ -398,7 +419,6 @@ void Connection::GetOperation(const Operation & op, OpVector & res)
             return;
         }
         info->setArgs1(o);
-        info->setSerialno(newSerialNo());
     }
     
     res.push_back(info);
