@@ -1,14 +1,29 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include <Python.h>
 
 #include "EntityFactory.h"
 
+#include "CorePropertyManager.h"
 #include "PersistantThingFactory.h"
 #include "ScriptFactory.h"
 #include "TaskFactory.h"
+#include "ArithmeticFactory.h"
 #include "Persistance.h"
 #include "Persistor.h"
 #include "Player.h"
@@ -44,6 +59,7 @@
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
 using Atlas::Message::ListType;
+using Atlas::Objects::Root;
 using Atlas::Objects::Entity::RootEntity;
 
 static const bool debug_flag = false;
@@ -56,9 +72,11 @@ EntityFactory::EntityFactory(BaseWorld & w) : m_world(w),
     installFactory("game_entity", "world", new ForbiddenThingFactory<World>());
     PersistantThingFactory<Thing> * tft = new PersistantThingFactory<Thing>();
     installFactory("game_entity", "thing", tft);
-    installFactory("thing", "feature", tft->duplicateFactory());
-    installFactory("feature", "line", new PersistantThingFactory<Line>());
-    installFactory("feature", "area", new PersistantThingFactory<Area>());
+    // FIXME #1 No longer need these three once Line and Area are removed from
+    // the code.
+    // installFactory("thing", "feature", tft->duplicateFactory());
+    // installFactory("feature", "line", new PersistantThingFactory<Line>());
+    // installFactory("feature", "area", new PersistantThingFactory<Area>());
     installFactory("thing", "character",
                    new PersistantThingFactory<Character>());
     installFactory("character", "creator",
@@ -69,6 +87,15 @@ EntityFactory::EntityFactory(BaseWorld & w) : m_world(w),
                    new PersistantThingFactory<Stackable>());
     installFactory("thing", "structure",
                    new PersistantThingFactory<Structure>());
+
+    m_statisticsFactories["settler"] = new PythonArithmeticFactory("world.statistics.Statistics", "Statistics");
+
+    new CorePropertyManager();
+}
+
+EntityFactory::~EntityFactory()
+{
+    delete PropertyManager::instance();
 }
 
 void EntityFactory::initWorld()
@@ -115,6 +142,8 @@ Entity * EntityFactory::newEntity(const std::string & id, long intId,
                         << std::endl << std::flush;);
         factory->m_scriptFactory->addScript(thing);
     }
+    //
+    factory->populate(*thing);
 
     // Read the defaults
     thing->merge(factory->m_attributes);
@@ -151,13 +180,51 @@ Entity * EntityFactory::newEntity(const std::string & id, long intId,
     return thing;
 }
 
-Task * EntityFactory::newTask(const std::string & name, Character & chr) const
+Task * EntityFactory::newTask(const std::string & name, Character & owner) const
 {
     TaskFactoryDict::const_iterator I = m_taskFactories.find(name);
     if (I == m_taskFactories.end()) {
         return 0;
     }
-    return I->second->newTask(chr);
+    return I->second->newTask(owner);
+}
+
+Task * EntityFactory::activateTask(const std::string & tool,
+                                   const std::string & op,
+                                   const std::string & target,
+                                   Character & owner) const
+{
+    TaskFactoryActivationDict::const_iterator I = m_taskActivations.find(tool);
+    if (I == m_taskActivations.end()) {
+        return 0;
+    }
+    const TaskFactoryMultimap & dict = I->second;
+    TaskFactoryMultimap::const_iterator J = dict.lower_bound(op);
+    if (J == dict.end()) {
+        return 0;
+    }
+    TaskFactoryMultimap::const_iterator Jend = dict.upper_bound(op);
+    for (; J != Jend; ++J) {
+        if (!J->second->m_target.empty()) {
+            if (!Inheritance::instance().isTypeOf(target, J->second->m_target)) {
+                debug( std::cout << target << " is not a " << J->second->m_target
+                                 << std::endl << std::flush; );
+                continue;
+            }
+        }
+        return J->second->newTask(owner);
+    }
+    return 0;
+}
+
+int EntityFactory::addStatisticsScript(Character & chr) const
+{
+    StatisticsFactoryDict::const_iterator I = m_statisticsFactories.begin();
+    if (I == m_statisticsFactories.end()) {
+        return -1;
+    }
+    I->second->newScript(chr);
+    return 0;
 }
 
 void EntityFactory::flushFactories()
@@ -169,6 +236,18 @@ void EntityFactory::flushFactories()
     delete m_eft;
     m_eft = NULL;
     m_factories.clear();
+    StatisticsFactoryDict::const_iterator J = m_statisticsFactories.begin();
+    StatisticsFactoryDict::const_iterator Jend = m_statisticsFactories.end();
+    for (; J != Jend; ++J) {
+        delete J->second;
+    }
+    m_statisticsFactories.clear();
+    TaskFactoryDict::const_iterator K = m_taskFactories.begin();
+    TaskFactoryDict::const_iterator Kend = m_taskFactories.end();
+    for (; K != Kend; ++K) {
+        delete K->second;
+    }
+    m_taskFactories.clear();
 }
 
 void EntityFactory::populateFactory(const std::string & className,
@@ -263,8 +342,8 @@ int EntityFactory::installTaskClass(const std::string & className,
     // if so, use it.
     MapType::const_iterator J = classDesc.find("script");
     MapType::const_iterator Jend = classDesc.end();
-    if ((J != Jend) && (J->second.isMap())) {
-        const MapType & script = J->second.asMap();
+    if ((J != Jend) && J->second.isMap()) {
+        const MapType & script = J->second.Map();
         J = script.find("name");
         if ((J != script.end()) && (J->second.isString())) {
             const std::string & script_name = J->second.String();
@@ -284,9 +363,34 @@ int EntityFactory::installTaskClass(const std::string & className,
         return -1;
     }
 
+    J = classDesc.find("activation");
+    if ((J != Jend) && J->second.isMap()) {
+        const MapType & activation = J->second.Map();
+        MapType::const_iterator act_end = activation.end();
+        J = activation.find("tool");
+        if (J != act_end && J->second.isString()) {
+            const std::string & activation_tool = J->second.String();
+            J = activation.find("operation");
+            if (J != act_end && J->second.isString()) {
+                const std::string & activation_op = J->second.String();
+                m_taskActivations[activation_tool].insert(std::make_pair(activation_op, factory));
+            }
+        }
+        J = activation.find("target");
+        if (J != act_end && J->second.isString()) {
+            const std::string & target_base = J->second.String();
+            factory->m_target = target_base;
+        }
+    }
+
     // std::cout << "Attempting to install " << className << " which is a "
               // << parent << std::endl << std::flush;
     m_taskFactories.insert(std::make_pair(className, factory));
+
+    Inheritance & i = Inheritance::instance();
+
+    i.addChild(atlasClass(className, parent));
+
     return 0;
 }
 
@@ -451,12 +555,12 @@ static void updateChildren(FactoryBase * factory)
     }
 }
 
-int EntityFactory::modifyRule(const std::string & className,
-                              const MapType & classDesc)
+int EntityFactory::modifyEntityClass(const std::string & className,
+                                     const Root & classDesc)
 {
     FactoryDict::const_iterator I = m_factories.find(className);
     if (I == m_factories.end()) {
-        log(ERROR, "Could not find factory for existing type.");
+        log(ERROR, String::compose("Could not find factory for existing entity class \"%1\".", className).c_str());
         return -1;
     }
     FactoryBase * factory = I->second;
@@ -469,19 +573,62 @@ int EntityFactory::modifyRule(const std::string & className,
 
     // Copy the defaults from the parent. In populateFactory this may be
     // overriden with the defaults for this class.
-    // FIXME
-    // If the code crashes here because m_parent is NULL, it is because
-    // the client has attempted to modify the factory for a core class.
-    factory->m_attributes = factory->m_parent->m_attributes;
+    if (factory->m_parent != 0) {
+        factory->m_attributes = factory->m_parent->m_attributes;
+    } else {
+        // This is non fatal, but nice to know it has happened.
+        // This should only happen if the client attempted to modify the
+        // type data for a core hard coded type.
+        log(ERROR, String::compose("EntityFactory::modifyEntityClass: \"%1\" modified by client, so has no parent factory", className).c_str());
+    }
     factory->m_classAttributes = MapType();
 
-    populateFactory(className, factory, classDesc);
+    populateFactory(className, factory, classDesc->asMessage());
 
     updateChildren(factory);
 
     return 0;
 }
 
+int EntityFactory::modifyTaskClass(const std::string & class_name,
+                                   const Root & classDesc)
+{
+    TaskFactoryDict::const_iterator I = m_taskFactories.find(class_name);
+    if (I == m_taskFactories.end()) {
+        log(ERROR, String::compose("Could not find factory for existing task class \"%1\"", class_name).c_str());
+        return -1;
+    }
+    // FIXME Actually update the task factory.
+    // TaskFactory * factory = I->second;
+    // assert(factory != 0);
+
+    return 0;
+}
+
+int EntityFactory::modifyOpDefinition(const std::string & class_name,
+                                      const Root & classDesc)
+{
+    // Nothing to actually do
+    return 0;
+}
+
+int EntityFactory::modifyRule(const std::string & class_name,
+                              const Root & classDesc)
+{
+    Root o = Inheritance::instance().getClass(class_name);
+    if (!o.isValid()) {
+        log(ERROR, String::compose("Could not find existing type \"%1\" in inheritance", class_name).c_str());
+        return -1;
+    }
+    if (o->getParents().front() == "task") {
+        return modifyTaskClass(class_name, classDesc);
+    } else if (classDesc->getObjtype() == "op_definition") {
+        return modifyOpDefinition(class_name, classDesc);
+    } else {
+        return modifyEntityClass(class_name, classDesc);
+    }
+}
+
 void EntityFactory::getRulesFromFiles(MapType & rules)
 {
     std::vector<std::string>::const_iterator I = rulesets.begin();
