@@ -1,12 +1,26 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include <Python.h>
 
 #include "PersistantThingFactory_impl.h"
 #include "Persistor.h"
 #include "ScriptFactory.h"
+#include "EntityFactory.h"
 
 #include "rulesets/Entity.h"
 #include "rulesets/Thing.h"
@@ -20,6 +34,8 @@
 #include "rulesets/Stackable.h"
 #include "rulesets/World.h"
 
+#include "common/log.h"
+
 FactoryBase::FactoryBase() : m_scriptFactory(0)
 {
 }
@@ -31,6 +47,13 @@ FactoryBase::~FactoryBase()
     }
 }
 
+template<>
+int PersistantThingFactory<Character>::populate(Entity & e)
+{
+    EntityFactory::instance()->addStatisticsScript((Character &)e);
+    return 0;
+}
+
 template class PersistorConnection<Entity>;
 template class PersistorConnection<Thing>;
 template class PersistorConnection<Character>;
