@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "Persistor.h"
 #include "Persistor_impl.h"
@@ -247,12 +260,12 @@ void Persistor<World>::update(World * t)
 template<>
 void Persistor<Character>::hookup(Character & t)
 {
-    t.updated.connect(SigC::bind<Character *>(SigC::slot(*this,
-                                              &Persistor<Character>::update),
-                                              &t));
-    t.destroyed.connect(SigC::bind<Character *>(SigC::slot(*this,
-                                                &Persistor<Character>::remove),
-                                                &t));
+    t.updated.connect(sigc::bind(sigc::mem_fun(this,
+                                               &Persistor<Character>::update),
+                                 &t));
+    t.destroyed.connect(sigc::bind(sigc::mem_fun(this,
+                                                 &Persistor<Character>::remove),
+                                   &t));
 }
 
 template<>
@@ -286,8 +299,8 @@ void Persistor<Creator>::persist(Creator & t)
 template<>
 void Persistor<World>::hookup(World & t)
 {
-    t.updated.connect(SigC::bind<World *>(SigC::slot(*this,
-                                          &Persistor<World>::update), &t));
+    t.updated.connect(sigc::bind(sigc::mem_fun(this, &Persistor<World>::update),
+                                 &t));
     // The game world should never be destroyed, so we don't connect
     // it to a remove function.
 }
