@@ -1,11 +1,24 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef SERVER_PERSISTOR_H
 #define SERVER_PERSISTOR_H
 
-#include <sigc++/object.h>
+#include <sigc++/trackable.h>
 
 #include <string>
 
@@ -18,7 +31,7 @@ class Plant;
 /// \brief Class template for handling persisting entity attributes in
 /// the database
 template <class T>
-class Persistor : virtual public SigC::Object {
+class Persistor : virtual public sigc::trackable {
   private:
     const std::string m_class;
 
