@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef SERVER_PERSISTOR_IMPL_H
 #define SERVER_PERSISTOR_IMPL_H
@@ -11,8 +24,8 @@
 
 #include "common/Database.h"
 
-#include <sigc++/bind.h>
-#include <sigc++/object_slot.h>
+#include <sigc++/adaptors/bind.h>
+#include <sigc++/functors/mem_fun.h>
 
 #include <sstream>
 
@@ -236,10 +249,10 @@ void Persistor<T>::cPlant(Plant & p, std::string & c, std::string & v)
 template <class T>
 void Persistor<T>::hookup(T & t)
 {
-    t.updated.connect(SigC::bind<T*>(SigC::slot(*this, &Persistor<T>::update),
-                                      &t));
-    t.destroyed.connect(SigC::bind<T*>(SigC::slot(*this, &Persistor<T>::remove),
-                                        &t));
+    t.updated.connect(sigc::bind(sigc::mem_fun(this, &Persistor<T>::update),
+                                 &t));
+    t.destroyed.connect(sigc::bind(sigc::mem_fun(this, &Persistor<T>::remove),
+                                   &t));
 }
 
 template <class T>
