@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
-// Copyright (C) 2000-2004 Alistair Riddoch
+// Cyphesis Online RPG Server and AI Engine
+// Copyright (C) 2000-2006 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "WorldRouter.h"
 
@@ -184,6 +197,8 @@ float WorldRouter::constrainHeight(Entity * parent, const Point3D & pos,
             h = 0;
         } else if (mode == "swimming") {
             h = std::max(h, std::min(0.f, pos.z()));
+        } else if (mode == "relative") {
+            h = h + pos.z();
         }
         debug(std::cout << "Fix height " << pos.z() << " to " << h
                         << std::endl << std::flush;);
@@ -191,7 +206,6 @@ float WorldRouter::constrainHeight(Entity * parent, const Point3D & pos,
     } else {
         static const Quaternion identity(Quaternion().identity());
         assert(parent->m_location.m_loc != 0);
-        // FIXME take account of orientation
         const Point3D & ppos = parent->m_location.pos();
         debug(std::cout << "parent " << parent->getId() << " of type "
                         << parent->getType() << " pos " << ppos.z()
@@ -237,11 +251,14 @@ Entity * WorldRouter::addEntity(Entity * ent, bool setup)
     ent->m_location.update(getTime());
     // FIXME
     std::string mode;
-    if (ent->has("mode")) {
+    if (ent->hasAttr("mode")) {
         Element mode_attr;
-        ent->get("mode", mode_attr);
+        ent->getAttr("mode", mode_attr);
         if (mode_attr.isString()) {
             mode = mode_attr.String();
+            if (mode == "relative") {
+                ent->setAttr("mode", "fixed");
+            }
         } else {
             log(ERROR, String::compose("Mode on entity is a %1 in WorldRouter::addEntity", Element::typeName(mode_attr.getType())).c_str());
         }
@@ -267,7 +284,6 @@ Entity * WorldRouter::addEntity(Entity * ent, bool setup)
         Setup s;
         s->setTo(ent->getId());
         s->setFutureSeconds(-0.1);
-        s->setSerialno(newSerialNo());
         message(s, m_gameWorld);
     }
     return ent;
@@ -285,7 +301,11 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
                     << std::endl << std::flush;);
     std::string id;
     long intId = newId(id);
-    assert(!id.empty());
+
+    if (intId < 0) {
+        log(ERROR, "Unable to get ID for new Entity");
+        return 0;
+    }
 
     Entity * ent = EntityFactory::instance()->newEntity(id, intId, typestr, attrs);
     if (ent == 0) {
@@ -297,6 +317,37 @@ Entity * WorldRouter::addNewEntity(const std::string & typestr,
     return addEntity(ent);
 }
 
+/// \brief Create a new task
+///
+/// Construct a new task linked to the Character provided.
+/// @param name the name of the task type to be instantiated
+/// @param owner the character who will own the task
+/// @return a pointer to the new task
+Task * WorldRouter::newTask(const std::string & name, Character & owner)
+{
+    Task * task = EntityFactory::instance()->newTask(name, owner);
+    if (task == 0) {
+        log(ERROR, String::compose("Attempt to create a task of type \"%1\" but type is unknown or forbidden", name).c_str());
+    }
+    return task;
+}
+
+/// \brief Activate a new task
+///
+/// Construct a task linked to the Character provided, activated by the
+/// tool and operation class given.
+/// @param tool the type of tool activating the task
+/// @param op the type of operation acitivating the task
+/// @param owner the character who will own the task
+/// @return a pointer to the new task
+Task * WorldRouter::activateTask(const std::string & tool,
+                                 const std::string & op,
+                                 const std::string & target,
+                                 Character & owner)
+{
+    return EntityFactory::instance()->activateTask(tool, op, target, owner);
+}
+
 /// \brief Remove an entity from the world.
 ///
 /// Remove an entity from the various lists in which it is stored.
@@ -374,9 +425,10 @@ void WorldRouter::deliverTo(const Operation & op, Entity & ent)
     OpVector::const_iterator Iend = res.end();
     for(OpVector::const_iterator I = res.begin(); I != Iend; ++I) {
         if (op->getFrom() == (*I)->getTo()) {
-            (*I)->setRefno(op->getSerialno());
+            if (!op->isDefaultSerialno() && (*I)->isDefaultRefno()) {
+                (*I)->setRefno(op->getSerialno());
+            }
         }
-        (*I)->setSerialno(newSerialNo());
         message(*I, ent);
     }
 }
@@ -461,13 +513,10 @@ void WorldRouter::operation(const Operation & op, Entity & from)
 /// to the entity to the set of perceptive entities. This method is
 /// called when key events occur that indicate that the entity in
 /// question can receive broadcase perception operations.
-void WorldRouter::addPerceptive(const std::string & id)
+void WorldRouter::addPerceptive(Entity * perceptive)
 {
     debug(std::cout << "WorldRouter::addPerceptive" << std::endl << std::flush;);
-    Entity * perceptive = getEntity(id);
-    if (perceptive != 0) {
-        m_perceptives.insert(perceptive);
-    }
+    m_perceptives.insert(perceptive);
 }
 
 /// Main world loop function.
