@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifndef SERVER_WORLD_ROUTER_H
 #define SERVER_WORLD_ROUTER_H
@@ -72,10 +85,13 @@ class WorldRouter : public BaseWorld {
     bool idle(int, int);
     Entity * addEntity(Entity * obj, bool setup = true);
     Entity * addNewEntity(const std::string &, const Atlas::Objects::Entity::RootEntity &);
+    Task * newTask(const std::string &, Character &);
+    Task * activateTask(const std::string &, const std::string &,
+                        const std::string &, Character &);
 
     void operation(const Operation &, Entity &);
 
-    virtual void addPerceptive(const std::string &);
+    virtual void addPerceptive(Entity *);
     virtual void message(const Operation &, Entity &);
     virtual Entity * findByName(const std::string & name);
     virtual Entity * findByType(const std::string & type);
