@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000-2004 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -33,7 +46,7 @@
 #include "common/system.h"
 #include "common/nls.h"
 
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 #include <sstream>
 
@@ -41,6 +54,11 @@ static const bool debug_flag = false;
 
 int main(int argc, char ** argv)
 {
+    if (security_check() != SECURITY_OKAY) {
+        log(CRITICAL, "Security Error. Exiting.");
+        return EXIT_SECURITY_ERROR;
+    }
+
     interactive_signals();
 
     if (loadConfig(argc, argv, true) < 0) {
@@ -108,6 +126,11 @@ int main(int argc, char ** argv)
     } else {
         server_name = get_hostname();
     }
+
+    int nice=0;
+    if (global_conf->findItem("cyphesis", "nice")) {
+        nice = global_conf->getItem("cyphesis", "nice");
+    }
     
     // Start up the python subsystem.
     init_python_api();
@@ -126,8 +149,13 @@ int main(int argc, char ** argv)
     // This ID is currently generated every time, but should perhaps be
     // persistent in future.
     std::string server_id, lobby_id;
-    long int_id = newId(server_id);
-    long lobby_int_id = newId(lobby_id);
+    long int_id, lobby_int_id;
+
+    if (((int_id = newId(server_id)) < 0) ||
+        ((lobby_int_id = newId(lobby_id)) < 0)) {
+        log(CRITICAL, "Unable to get server IDs from Database");
+        return EXIT_DATABASE_ERROR;
+    }
 
     ServerRouting server(world, rulesets.front(), server_name,
                          server_id, int_id,
@@ -159,7 +187,7 @@ int main(int argc, char ** argv)
     } else {
         std::string adminId;
         long intId = newId(adminId);
-        assert(!adminId.empty());
+        assert(intId >= 0);
 
         Admin * admin = new Admin(0, "admin", "BAD_HASH", adminId, intId);
         server.addAccount(admin);
@@ -216,10 +244,17 @@ int main(int argc, char ** argv)
 #endif // defined(HAVE_LIBHOWL)
 
     log(INFO, "Running");
+    logEvent(START, "- - - Standalone server startup");
 
     // Inform things that want to know that we are running.
     running();
 
+    // Reduce our system priority to make it easier to debug a runaway
+    // server.
+    if (nice != 0) {
+        reduce_priority(nice);
+    }
+
     // Loop until the exit flag is set. The exit flag can be set anywhere in
     // the code easily.
     while (!exit_flag) {
@@ -262,5 +297,6 @@ int main(int argc, char ** argv)
     delete global_conf;
 
     log(INFO, "Clean shutdown complete.");
+    logEvent(STOP, "- - - Standalone server shutdown");
     return 0;
 }
