@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2000,2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "CommServer.h"
 #include "CommSlaveListener.h"
@@ -20,7 +33,7 @@
 #include "common/inheritance.h"
 #include "common/system.h"
 
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 static const bool debug_flag = false;
 
@@ -101,8 +114,14 @@ int main(int argc, char ** argv)
     // This ID is currently generated every time, but should perhaps be
     // persistent in future.
     std::string server_id, lobby_id;
-    long int_id = newId(server_id);
-    long lobby_int_id = newId(lobby_id);
+    std::string server_id, lobby_id;
+    long int_id, lobby_int_id;
+
+    if (((int_id = newId(server_id)) < 0) ||
+        ((lobby_int_id = newId(lobby_id)) < 0)) {
+        log(CRITICAL, "Unable to get server IDs from Database");
+        return EXIT_DATABASE_ERROR;
+    }
 
     ServerRouting server(world, rulesets.front(), serverName,
                          server_id, int_id,
@@ -131,7 +150,10 @@ int main(int argc, char ** argv)
     commServer.addSocket(listener);
 
     std::string master_id;
-    newId(master_id);
+    if (newId(master_id) < 0) {
+        log(CRITICAL, "Unable to get master ID from Database");
+        return EXIT_DATABASE_ERROR;
+    }
 
     CommMaster * master = new CommMaster(commServer, serverHostname, master_id);
     if (master->connect(serverHostname) != 0) {
