@@ -1,10 +1,24 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2005 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "TestWorld.h"
 
 #include "rulesets/World.h"
+#include "rulesets/Python_API.h"
 
 #include "server/EntityFactory.h"
 #include "server/PersistantThingFactory.h"
@@ -53,8 +67,12 @@ class ExposedEntityFactory : public EntityFactory {
 
 };
 
-int main()
+int main(int argc, char ** argv)
 {
+    loadConfig(argc, argv);
+
+    init_python_api();
+
     int ret;
 
     {
@@ -86,14 +104,14 @@ int main()
 
         Entity * test_ent = EntityFactory::instance()->newEntity("1", 1, "thing", attributes);
         assert(test_ent != 0);
-        assert(!test_ent->get("funky", val));
+        assert(!test_ent->getAttr("funky", val));
         assert(val.isNone());
 
         attributes->setAttr("funky", "true");
 
         test_ent = EntityFactory::instance()->newEntity("1", 1, "thing", attributes);
         assert(test_ent != 0);
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -119,7 +137,7 @@ int main()
         assert(test_ent != 0);
         // Check the created entity does not have the attribute values we
         // will be testing later
-        assert(!test_ent->get("funky", val));
+        assert(!test_ent->getAttr("funky", val));
         assert(val.isNone());
 
         // Set a test attribute
@@ -129,7 +147,7 @@ int main()
         // attribute value
         test_ent = entity_factory.newEntity("1", 1, "thing", attributes);
         assert(test_ent != 0);
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -185,7 +203,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -195,7 +213,7 @@ int main()
 
         // Check the custom type has the attribute described when the
         // custom type was installed.
-        assert(test_ent->get("test_custom_type_attr", val));
+        assert(test_ent->getAttr("test_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_value");
 
@@ -254,7 +272,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -264,7 +282,7 @@ int main()
 
         // Check the instance of the second custom type has the attribute
         // described when the first custom type was installed.
-        assert(test_ent->get("test_custom_type_attr", val));
+        assert(test_ent->getAttr("test_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_value");
 
@@ -274,7 +292,7 @@ int main()
 
         // Check the custom type has the attribute described when the
         // second custom type was installed
-        assert(test_ent->get("test_custom_inherited_type_attr", val));
+        assert(test_ent->getAttr("test_custom_inherited_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_inherited_value");
 
@@ -282,7 +300,7 @@ int main()
 
         // Make sure than attempting to modify a non-existant type fails
         {
-            MapType nonexistant_description;
+            Anonymous nonexistant_description;
             MapType attrs;
             MapType test_custom_type_attr;
 
@@ -290,7 +308,7 @@ int main()
             test_custom_type_attr["visibility"] = "public";
             attrs["no_custom_type_attr"] = test_custom_type_attr;
 
-            nonexistant_description["attributes"] = attrs;
+            nonexistant_description->setAttr("attributes", attrs);
 
             ret = entity_factory.modifyRule("nonexistant", nonexistant_description);
 
@@ -299,8 +317,8 @@ int main()
 
         // Modify the second custom type removing its custom attribute
         {
-            MapType new_custom_inherited_type_description;
-            new_custom_inherited_type_description["attributes"] = MapType();
+            Anonymous new_custom_inherited_type_description;
+            new_custom_inherited_type_description->setAttr("attributes", MapType());
 
             ret = entity_factory.modifyRule("custom_inherited_type", new_custom_inherited_type_description);
 
@@ -334,9 +352,9 @@ int main()
         assert(val.isNone());
 
         // Make sure test nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant", val));
+        assert(!test_ent->getAttr("nonexistant", val));
         // Make sure nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant_attribute", val));
+        assert(!test_ent->getAttr("nonexistant_attribute", val));
 
         // Reset val.
         val = Atlas::Message::Element();
@@ -344,7 +362,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -354,7 +372,7 @@ int main()
 
         // Check the instance of the second custom type has the attribute
         // described when the first custom type was installed.
-        assert(test_ent->get("test_custom_type_attr", val));
+        assert(test_ent->getAttr("test_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_value");
 
@@ -364,12 +382,12 @@ int main()
 
         // Check the custom type has the attribute described when the
         // second custom type was installed
-        assert(!test_ent->get("test_custom_inherited_type_attr", val));
+        assert(!test_ent->getAttr("test_custom_inherited_type_attr", val));
 
         // Modify the first custom type removing its custom attribute
         {
-            MapType new_custom_type_description;
-            new_custom_type_description["attributes"] = MapType();
+            Anonymous new_custom_type_description;
+            new_custom_type_description->setAttr("attributes", MapType());
 
             ret = entity_factory.modifyRule("custom_type", new_custom_type_description);
 
@@ -397,7 +415,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -406,7 +424,7 @@ int main()
         assert(val.isNone());
 
         // Check the custom type no longer has the custom attribute
-        assert(!test_ent->get("test_custom_type_attr", val));
+        assert(!test_ent->getAttr("test_custom_type_attr", val));
 
         // Check that the factory dictionary does contain the factory for
         // the second newly installed type
@@ -433,9 +451,9 @@ int main()
         assert(val.isNone());
 
         // Make sure test nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant", val));
+        assert(!test_ent->getAttr("nonexistant", val));
         // Make sure nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant_attribute", val));
+        assert(!test_ent->getAttr("nonexistant_attribute", val));
 
         // Reset val.
         val = Atlas::Message::Element();
@@ -443,7 +461,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -453,7 +471,7 @@ int main()
 
         // Check the instance of the second custom type has the attribute
         // described when the first custom type was installed.
-        assert(!test_ent->get("test_custom_type_attr", val));
+        assert(!test_ent->getAttr("test_custom_type_attr", val));
 
         // Reset val.
         val = Atlas::Message::Element();
@@ -461,11 +479,11 @@ int main()
 
         // Check the custom type has the attribute described when the
         // second custom type was installed
-        assert(!test_ent->get("test_custom_inherited_type_attr", val));
+        assert(!test_ent->getAttr("test_custom_inherited_type_attr", val));
 
         // Add more custom attributes to the first type
         {
-            MapType new_custom_type_description;
+            Anonymous new_custom_type_description;
             MapType attrs;
             MapType test_custom_type_attr;
 
@@ -479,7 +497,7 @@ int main()
             new_custom_type_attr["visibility"] = "public";
             attrs["new_custom_type_attr"] = new_custom_type_attr;
 
-            new_custom_type_description["attributes"] = attrs;
+            new_custom_type_description->setAttr("attributes", attrs);
 
             ret = entity_factory.modifyRule("custom_type", new_custom_type_description);
 
@@ -515,7 +533,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -524,11 +542,11 @@ int main()
         assert(val.isNone());
 
         // Check the custom type now has the custom attributes
-        assert(test_ent->get("test_custom_type_attr", val));
+        assert(test_ent->getAttr("test_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_value");
 
-        assert(test_ent->get("new_custom_type_attr", val));
+        assert(test_ent->getAttr("new_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "new_value");
 
@@ -564,9 +582,9 @@ int main()
         assert(val.isNone());
 
         // Make sure test nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant", val));
+        assert(!test_ent->getAttr("nonexistant", val));
         // Make sure nonexistant attribute isn't present
-        assert(!test_ent->get("nonexistant_attribute", val));
+        assert(!test_ent->getAttr("nonexistant_attribute", val));
 
         // Reset val.
         val = Atlas::Message::Element();
@@ -574,7 +592,7 @@ int main()
 
         // Check the custom type has the attribute we passed in when creating
         // the instance.
-        assert(test_ent->get("funky", val));
+        assert(test_ent->getAttr("funky", val));
         assert(val.isString());
         assert(val.String() == "true");
 
@@ -584,11 +602,11 @@ int main()
 
         // Check the instance of the second custom type has the attribute
         // described when the first custom type was installed.
-        assert(test_ent->get("test_custom_type_attr", val));
+        assert(test_ent->getAttr("test_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "test_value");
 
-        assert(test_ent->get("new_custom_type_attr", val));
+        assert(test_ent->getAttr("new_custom_type_attr", val));
         assert(val.isString());
         assert(val.String() == "new_value");
 
@@ -598,7 +616,7 @@ int main()
 
         // Check the custom type no longer has the attribute described when the
         // second custom type was installed
-        assert(!test_ent->get("test_custom_inherited_type_attr", val));
+        assert(!test_ent->getAttr("test_custom_inherited_type_attr", val));
 
     }
 }
