@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2003 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #include "IGEntityExerciser.h"
 #include "allOperations.h"
@@ -54,19 +67,19 @@ int main()
     assert(!ee.checkProperties(attrNames));
 
     // Add the test attributes
-    e.set("test_int", 1);
-    e.set("test_float", 1.f);
-    e.set("test_list_string", "test_value");
-    e.set("test_list_int", ListType(1, 1));
-    e.set("test_list_float", ListType(1, 1.f));
-    e.set("test_map_string", ListType(1, "test_value"));
+    e.setAttr("test_int", 1);
+    e.setAttr("test_float", 1.f);
+    e.setAttr("test_list_string", "test_value");
+    e.setAttr("test_list_int", ListType(1, 1));
+    e.setAttr("test_list_float", ListType(1, 1.f));
+    e.setAttr("test_map_string", ListType(1, "test_value"));
     MapType test_map;
     test_map["test_key"] = 1;
-    e.set("test_map_int", test_map);
+    e.setAttr("test_map_int", test_map);
     test_map["test_key"] = 1.f;
-    e.set("test_map_float", test_map);
+    e.setAttr("test_map_float", test_map);
     test_map["test_key"] = "test_value";
-    e.set("test_map_string", test_map);
+    e.setAttr("test_map_string", test_map);
     
     // Make sure we have the test attributes now
     assert(ee.checkAttributes(attrNames));
