@@ -1,6 +1,19 @@
-// This file may be redistributed and modified only under the terms of
-// the GNU General Public License (See COPYING for details).
+// Cyphesis Online RPG Server and AI Engine
 // Copyright (C) 2001 Alistair Riddoch
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+// 
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+// 
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation,
+// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -20,15 +33,13 @@
 #include <Atlas/Objects/Anonymous.h>
 #include <Atlas/Objects/Operation.h>
 
-#include <varconf/Config.h>
+#include <varconf/config.h>
 
 #include "common/Monitor.h"
 #include "common/Connect.h"
 
 #include <skstream/skstream_unix.h>
 
-#include <sigc++/object_slot.h>
-#include <sigc++/signal.h>
 #include <sigc++/connection.h>
 
 #ifndef READLINE_CXX_SANE   // defined in config.h
@@ -256,7 +267,8 @@ class OperationMonitor : public AdminTask {
 };
 
 template <class Stream>
-class Interactive : public Atlas::Objects::ObjectsDecoder, public SigC::Object
+class Interactive : public Atlas::Objects::ObjectsDecoder,
+                    virtual public sigc::trackable
 {
   private:
     bool error_flag, reply_flag, login_flag, avatar_flag;
@@ -601,7 +613,7 @@ void Interactive<Stream>::soundArrived(const RootOperation & op)
               << std::endl << std::flush;
 }
 
-SigC::Signal1<void, char *> CmdLine;
+sigc::signal<void, char *> CmdLine;
 
 template <class Stream>
 void Interactive<Stream>::gotCommand(char * cmd)
@@ -691,11 +703,10 @@ void Interactive<Stream>::loop()
 {
     rl_callback_handler_install("cyphesis> ", &Interactive<Stream>::gotCommand);
     rl_completion_entry_function = &completion_generator;
-    SigC::Connection c = CmdLine.connect(SigC::slot(*this, &Interactive<Stream>::runCommand));
+    CmdLine.connect(sigc::mem_fun(this, &Interactive<Stream>::runCommand));
     while (!exit) {
         poll();
     };
-    c.disconnect();
     rl_callback_handler_remove();
 }
 
@@ -852,14 +863,14 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
             std::cout << "usage: install <type id> <parent id>"
                       << std::endl << std::flush;
         } else {
-            Set s;
-            s->setFrom(accountId);
+            Create c;
+            c->setFrom(accountId);
             Anonymous ent;
             ent->setId(std::string(arg, 0, space));
             ent->setObjtype("class");
             ent->setParents(std::list<std::string>(1, std::string(arg, space + 1)));
-            s->setArgs1(ent);
-            encoder->streamObjectsMessage(s);
+            c->setArgs1(ent);
+            encoder->streamObjectsMessage(c);
         }
         reply_expected = false;
     } else if (cmd == "look") {
@@ -976,6 +987,7 @@ void Interactive<Stream>::exec(const std::string & cmd, const std::string & arg)
 
         Anonymous cmap;
         cmap->setParents(std::list<std::string>(1, "creator"));
+        cmap->setName("cycmd agent");
         cmap->setObjtype("obj");
         c->setArgs1(cmap);
         c->setFrom(accountId);
